# 无障碍

- order: 7

通过`okProps`与`cancelProps`设置`aria-label`属性，屏幕阅读器读取确定和取消按钮。关于键盘操作请参考`ARIA and KeyBoard`。

:::lang=en-us
# Accessibility

- order: 7

Set the `aria-label` attribute via `okProps` and `cancelProps`, The screen reader will read the OK and Cancel buttons. Please refer to `ARIA and KeyBoard` for keyboard operation.

:::
---

````jsx

import { Button, Dialog } from '@alifd/next';

class Demo extends React.Component {
    state = {
        visible: false
    };
    onOpen = () => {
        this.setState({
            visible: true
        });
    };
    onClose = () => {
        this.setState({
            visible: false
        });
    };
    render() {
        return (
            <div>
                <Button onClick={this.onOpen} type="primary">
                    Open dialog
                </Button>
                <Dialog
                    title="Welcome to Alibaba.com"
                    visible={this.state.visible}
                    autoFocus
                    onOk={this.onClose.bind(this, 'okClick')}
                    onCancel={this.onClose.bind(this, 'cancelClick')}
                    onClose={this.onClose}
                    cancelProps={{'aria-label':'cancel'}}
                    okProps={{'aria-label':'ok'}}>
                    <p tabIndex="0">  Start your business here by searching a popular product</p>
                </Dialog>
            </div>
        );
    }
}

ReactDOM.render(<Demo />, mountNode);

````
