# Tree

-   category: Components
-   family: DataDisplay
-   chinese: 树形控件
-   type: 基本

---

## Guide

### When To Use

Folders, organizational structures, taxonomy, countries, regions, etc. Most of the structures in the world are tree structures. The use of Tree can fully reveal the hierarchical relationships among them, and have interactive functions such as expanding and closing, selections.

## API

### Tree

| Param | Descripiton  | Type  | Default Value |
| ------------------- | ---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ----------------------- | ---------- |
| children            | tree nodes                                                                                                                                                                                                                                                                                                                                                                                                              | ReactNode               | -          |
| dataSource          | data source, this property has a higher priority than children                                                                                                                                                                                                                                                                                                                                                                                            | Array                   | -          |
| showLine            | whether to show the line of the tree                                                                                                                                                                                                                                                                                                                                                                                                          | Boolean                 | false      |
| selectable          | whether to support selecting node                                                                                                                                                                                                                                                                                                                                                                                                         | Boolean                 | true       |
| selectedKeys        | (under control) keys of current selected nodes                                                                                                                                                                                                                                                                                                                                                                                             | Array&lt;String>        | -          |
| defaultSelectedKeys | (under uncontrol) keys of default selected nodes                                                                                                                                                                                                                                                                                                                                                                                           | Array&lt;String>        | \[]        |
| onSelect            | callback function triggered when select or unselect node<br><br>**signatures**:<br>Function(selectedKeys: Array, extra: Object) => void<br>**params**:<br>_selectedKeys_: {Array} keys of selected nodes<br>_extra_: {Object} extra params<br>_extra.selectedNodes_: {Array} selected nodes<br>_extra.node_: {Object} current operation node<br>_extra.selected_: {Boolean} whether is selected                                                                                                                         | Function                | () => {}   |
| multiple            | whether to support multiple selection                                                                                                                                                                                                                                                                                                                                                                                                           | Boolean                 | false      |
| checkable           | whether to support checking checkbox of the node                                                                                                                                                                                                                                                                                                                                                                                                   | Boolean                 | false      |
| checkedKeys         | (under control) keys of current checked nodes, it should be an array or an object like `{checked: Array, indeterminate: Array}`                                                                                                                                                                                                                                                                                                                                           | Array&lt;String>/Object | -          |
| defaultCheckedKeys  | (under uncontrol) keys of default checked nodes                                                                                                                                                                                                                                                                                                                                                                                         | Array&lt;String>        | \[]        |
| checkStrictly       | whether the checkbox of the node is controlled strictly (selection of parent and child nodes are no longer related)                                                                                                                                                                                                                                                                                                                                                                                      | Boolean                 | false      |
| checkedStrategy     | defining the way to backfill when checked node <br><br>**options**:<br>'all' (return all checked nodes)<br>'parent' (only parent nodes are returned when parent and child nodes are checked) <br>'child' (only child nodes are returned when parent and child nodes are checked)                                                                                                                                                                                                                                                                                                            | Enum                    | 'all'      |
| onCheck             | callback function triggered when check or uncheck node<br><br>**signatures**:<br>Function(checkedKeys: Array, extra: Object) => void<br>**params**:<br>_checkedKeys_: {Array} keys of checked nodes<br>_extra_: {Object} extra param<br>_extra.checkedNodes_: {Array} checked nodes<br>_extra.checkedNodesPositions_: {Array} an array containing objects with check box nodes and their locations<br>_extra.indeterminateKeys_: {Array} keys of indeterminate nodes<br>_extra.node_: {Object} current operation node<br>_extra.checked_: {Boolean} whethre is checked | Function                | () => {}   |
| expandedKeys        | (under control) keys of current expanded nodes                                                                                                                                                                                                                                                                                                                                                                                            | Array&lt;String>        | -          |
| defaultExpandedKeys | (under uncontrol) keys of default expanded nodes                                                                                                                                                                                                                                                                                                                                                                                           | Array&lt;String>        | \[]        |
| defaultExpandAll    | whether to expand all nodes by default                                                                                                                                                                                                                                                                                                                                                                                                       | Boolean                 | false      |
| autoExpandParent    | whether to expand the parent node automatically                                                                                                                                                                                                                                                                                                                                                                                                        | Boolean                 | true       |
| onExpand            | callback function triggered when expand or collapse node<br><br>**signatures**:<br>Function(expandedKeys: Array, extra: Object) => void<br>**params**:<br>_expandedKeys_: {Array} keys of expanded nodes<br>_extra_: {Object} extra param<br>_extra.node_: {Object} current operation node<br>_extra.expanded_: {Boolean} whether is expanded                                                                                                                                                                    | Function                | () => {}   |
| editable            | whether to support editing node content                                                                                                                                                                                                                                                                                                                                                                                                       | Boolean                 | false      |
| onEditFinish        | callback function triggered after editing<br><br>**signatures**:<br>Function(key: String, label: String, node: Object) => void<br>**params**:<br>_key_: {String}  key of editing node<br>_label_: {String} label after editting<br>_node_: {Object} editting node                                                                                                                                                                                                              | Function                | () => {}   |
| draggable           | whether to support drag and drop nodes                                                                                                                                                                                                                                                                                                                                                                                                         | Boolean                 | false      |
| onDragStart         | callback function triggered when start to drag node<br><br>**signatures**:<br>Function(info: Object) => void<br>**params**:<br>_info_: {Object} drag and drop information<br>_info.event_: {Object} event object<br>_info.node_: {Object} drag node                                                                                                                                                                                                                                                | Function                | () => {}   |
| onDragEnter         | callback function triggered when the drag node enters the target node<br><br>**signatures**:<br>Function(info: Object) => void<br>**params**:<br>_info_: {Object} drag and drop information<br>_info.event_: {Object} event object<br>_info.node_: {Object} target node<br>_info.expandedKeys_: {Array} keys of current expanded nodes                                                                                                                                                                                               | Function                | () => {}   |
| onDragOver          | callback function triggered when the drag node is moved on the target node<br><br>**signatures**:<br>Function(info: Object) => void<br>**params**:<br>_info_: {Object} drag and drop information<br>_info.event_: {Object} event object<br>_info.node_: {Object} target node                                                                                                                                                                                                                                         | Function                | () => {}   |
| onDragLeave         | callback function triggered when the drag node leaves the target node<br><br>**signatures**:<br>Function(info: Object) => void<br>**params**:<br>_info_: {Object} drag and drop information<br>_info.event_: {Object} event object<br>_info.node_: {Object} target node                                                                                                                                                                                                                                             | Function                | () => {}   |
| onDragEnd           | callback function triggered after draging<br><br>**signatures**:<br>Function(info: Object) => void<br>**params**:<br>_info_: {Object} drag and drop information<br>_info.event_: {Object} event object<br>_info.node_: {Object} target node                                                                                                                                                                                                                                               | Function                | () => {}   |
| onDrop              | callback function triggered when drop the node<br><br>**signatures**:<br>Function(info: Object) => void<br>**params**:<br>_info_: {Object} drag and drop information<br>_info.event_: {Object} event object<br>_info.node_: {Object} target node<br>_info.dragNode_: {Object} drag node<br>_info.dragNodesKeys_: {Array} keys of drag node and its child nodes<br>_info.dropPosition_: {Number} drop position, -1 means before the current node, 0 means in the current node, and 1 means after the current node                                                                                 | Function                | () => {}   |
| canDrop             | whether the node can be used as a drag target node<br><br>**signatures**:<br>Function(info: Object) => Boolean<br>**params**:<br>_info_: {Object} drag and drop information<br>_info.node_: {Object} target node<br>_info.dragNode_: {Object} drag node<br>_info.dragNodesKeys_: {Array} keys of drag node and its child nodes<br>_info.dropPosition_: {Number} drop position, -1 means before the current node, 0 means in the current node, and 1 means after the current node<br>**returns**:<br>{Boolean} Can it be treated as a target node<br>                                                                          | Function                | () => true |
| loadData            | asynchronous data loading function<br><br>**signatures**:<br>Function(node: Object) => void<br>**params**:<br>_node_: {Object} node clicked to expand                                                                                                                                                                                                                                                                                                               | Function                | -          |
| filterTreeNode      | filter highlight nodes<br><br>**signatures**:<br>Function(node: Object) => Boolean<br>**params**:<br>_node_: {Object} nodes to be filtered<br>**returns**:<br>{Boolean} whether is filtered<br>                                                                                                                                                                                                                                                                           | Function                | -          |
| onRightClick        | callback function when right click<br><br>**signatures**:<br>Function(info: Object) => void<br>**params**:<br>_info_: {Object} information object<br>_info.event_: {Object} event object<br>_info.node_: {Object} clicked node                                                                                                                                                                                                                                                | Function                | -          |
| isLabelBlock        | sets whether or not the node occupies the remaining space, it is generally used to add elements to the right side of each node (base flex, only Internet Explorer 10+ is supported)                                                                                                                                                                                                                                                                                                                                                           | Boolean                 | false      |
| isNodeBlock         | set whether the node fills a row                                                                                                                                                                                                                                                                                                                                                                                                       | Boolean/Object          | false      |
| animation           | whether to enable expand and collapse animation                                                                                                                                                                                                                                                                                                                                                                                                       | Boolean                 | true       |
| renderChildNodes    | Render child nodes<br><br>**签名**:<br>Function(nodes: Array) => ReactNode<br>**params**:<br>_nodes_: {Array} child nodes<br>**返回值**:<br>{ReactNode} <br>                                                                                                                                                                                                                                                                            | Function                | -          |

### Tree.Node

| Param | Descripiton  | Type  | Default Value |
| ---------------- | ------------------------------- | --------- | ----- |
| children         | tree nodes                             | ReactNode | -     |
| label            | content of node                          | ReactNode | '---' |
| selectable       | set whether to support selecting node, override the Tree's selectable | Boolean   | -     |
| checkable        | set whether to support checking node, override the Tree's checkable | Boolean   | -     |
| editable         | set whether to support editing node, override the Tree's editable   | Boolean   | -     |
| draggable        | set whether to support dragging node, override the Tree's draggable  | Boolean   | -     |
| disabled         | whether node is disabled                        | Boolean   | false |
| checkboxDisabled | whether checkbox of node is disabled                      | Boolean   | false |
| isLeaf           | whether it is a leaf node and only works when loadData is set           | Boolean   | false |

<!-- api-extra-start -->

You should set the `key` for Tree.Node: `<TreeNode key="102894" label="Ladies" />`, which is generally the id of the data, but it must be guaranteed globally unique. The default value of `key` is Tree's internally calculated position string.

<!-- api-extra-end -->
