{"title":"Custom cell","meta":{"title":"Custom cell","description":"\n<p>Render custom contents in <code>dateCellRender</code> and <code>monthCellRender</code>.</p>\n","order":"3"},"codes":{"jsx":"import { Calendar } from '@alifd/next';\nimport moment from 'moment';\n\nconst currentDate = moment();\nconst localeData = currentDate.clone().localeData();\nconst monthLocale = localeData.monthsShort();\n\n\nfunction dateCellRender(date) {\n    const dateNum = date.date();\n    if (currentDate.month() !== date.month()) {\n        return dateNum;\n    }\n\n    let eventList;\n    switch (dateNum) {\n        case 1:\n            eventList = [\n                { type: 'primary', content: 'Event 1' },\n                { type: 'normal', content: 'Event 2' }\n            ];\n            break;\n        case 10:\n            eventList = [\n                { type: 'normal', content: 'Event 3' },\n                { type: 'normal', content: 'Event 4' }\n            ];\n            break;\n        case 11:\n            eventList = [\n                { type: 'primary', content: 'Event 5' },\n                { type: 'primary', content: 'Event 6' }\n            ];\n            break;\n        default:\n            eventList = [];\n    }\n\n    return (<div className=\"custom-calendar-cell\">\n        <div className=\"custom-calendar-cell-value\">{dateNum}</div>\n        <div className=\"custom-calendar-cell-content\">\n            <ul className=\"event-list\">\n                {eventList.map((item, key) => <li className={`${item.type}-event`} key={key}>{item.content}</li>)}\n            </ul>\n        </div>\n    </div>);\n}\n\nfunction monthCellRender(date) {\n    if (currentDate.month() === date.month()) {\n        return (<div>\n            <div>{monthLocale[date.month()]}</div>\n            <div>Events</div>\n        </div>);\n    }\n    return monthLocale[date.month()];\n}\n\nReactDOM.render(<Calendar dateCellRender={dateCellRender} monthCellRender={monthCellRender} />, mountNode);\n","css":".custom-calendar-guide {\n    width: 270px;\n    border: 1px solid #C4C6CF;\n    border-radius: 3px;\n    overflow: hidden;\n    margin-top: 20px;\n}\n\n.custom-calendar-cell-content {\n    height: 50px;\n    text-align: left;\n}\n\n.event-list {\n    margin: 0;\n    padding: 0;\n    list-style: none;\n}\n\n.primary-event {\n    color: white;\n    background: red;\n    border-radius: 3px;\n    padding-left: 10px;\n    margin-bottom: 3px;\n}\n\n.normal-event {\n    color: white;\n    background: blue;\n    border-radius: 3px;\n    padding-left: 10px;\n    margin-bottom: 3px;\n}\n"},"body":"\n````jsx\nimport { Calendar } from '@alifd/next';\nimport moment from 'moment';\n\nconst currentDate = moment();\nconst localeData = currentDate.clone().localeData();\nconst monthLocale = localeData.monthsShort();\n\n\nfunction dateCellRender(date) {\n    const dateNum = date.date();\n    if (currentDate.month() !== date.month()) {\n        return dateNum;\n    }\n\n    let eventList;\n    switch (dateNum) {\n        case 1:\n            eventList = [\n                { type: 'primary', content: 'Event 1' },\n                { type: 'normal', content: 'Event 2' }\n            ];\n            break;\n        case 10:\n            eventList = [\n                { type: 'normal', content: 'Event 3' },\n                { type: 'normal', content: 'Event 4' }\n            ];\n            break;\n        case 11:\n            eventList = [\n                { type: 'primary', content: 'Event 5' },\n                { type: 'primary', content: 'Event 6' }\n            ];\n            break;\n        default:\n            eventList = [];\n    }\n\n    return (<div className=\"custom-calendar-cell\">\n        <div className=\"custom-calendar-cell-value\">{dateNum}</div>\n        <div className=\"custom-calendar-cell-content\">\n            <ul className=\"event-list\">\n                {eventList.map((item, key) => <li className={`${item.type}-event`} key={key}>{item.content}</li>)}\n            </ul>\n        </div>\n    </div>);\n}\n\nfunction monthCellRender(date) {\n    if (currentDate.month() === date.month()) {\n        return (<div>\n            <div>{monthLocale[date.month()]}</div>\n            <div>Events</div>\n        </div>);\n    }\n    return monthLocale[date.month()];\n}\n\nReactDOM.render(<Calendar dateCellRender={dateCellRender} monthCellRender={monthCellRender} />, mountNode);\n````\n\n````css\n.custom-calendar-guide {\n    width: 270px;\n    border: 1px solid #C4C6CF;\n    border-radius: 3px;\n    overflow: hidden;\n    margin-top: 20px;\n}\n\n.custom-calendar-cell-content {\n    height: 50px;\n    text-align: left;\n}\n\n.event-list {\n    margin: 0;\n    padding: 0;\n    list-style: none;\n}\n\n.primary-event {\n    color: white;\n    background: red;\n    border-radius: 3px;\n    padding-left: 10px;\n    margin-bottom: 3px;\n}\n\n.normal-event {\n    color: white;\n    background: blue;\n    border-radius: 3px;\n    padding-left: 10px;\n    margin-bottom: 3px;\n}\n````","html":"<script>(function(){'use strict';\n\nvar _next = require('@alifd/next');\n\nvar _moment = require('moment');\n\nvar _moment2 = _interopRequireDefault(_moment);\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }\n\nvar currentDate = (0, _moment2.default)();\nvar localeData = currentDate.clone().localeData();\nvar monthLocale = localeData.monthsShort();\n\nfunction dateCellRender(date) {\n    var dateNum = date.date();\n    if (currentDate.month() !== date.month()) {\n        return dateNum;\n    }\n\n    var eventList = void 0;\n    switch (dateNum) {\n        case 1:\n            eventList = [{ type: 'primary', content: 'Event 1' }, { type: 'normal', content: 'Event 2' }];\n            break;\n        case 10:\n            eventList = [{ type: 'normal', content: 'Event 3' }, { type: 'normal', content: 'Event 4' }];\n            break;\n        case 11:\n            eventList = [{ type: 'primary', content: 'Event 5' }, { type: 'primary', content: 'Event 6' }];\n            break;\n        default:\n            eventList = [];\n    }\n\n    return React.createElement(\n        'div',\n        { className: 'custom-calendar-cell' },\n        React.createElement(\n            'div',\n            { className: 'custom-calendar-cell-value' },\n            dateNum\n        ),\n        React.createElement(\n            'div',\n            { className: 'custom-calendar-cell-content' },\n            React.createElement(\n                'ul',\n                { className: 'event-list' },\n                eventList.map(function (item, key) {\n                    return React.createElement(\n                        'li',\n                        { className: item.type + '-event', key: key },\n                        item.content\n                    );\n                })\n            )\n        )\n    );\n}\n\nfunction monthCellRender(date) {\n    if (currentDate.month() === date.month()) {\n        return React.createElement(\n            'div',\n            null,\n            React.createElement(\n                'div',\n                null,\n                monthLocale[date.month()]\n            ),\n            React.createElement(\n                'div',\n                null,\n                'Events'\n            )\n        );\n    }\n    return monthLocale[date.month()];\n}\n\nReactDOM.render(React.createElement(_next.Calendar, { dateCellRender: dateCellRender, monthCellRender: monthCellRender }), mountNode);})()</script><div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\"><span class=\"token keyword\">import</span> <span class=\"token punctuation\">{</span> Calendar <span class=\"token punctuation\">}</span> <span class=\"token keyword\">from</span> <span class=\"token string\">'@alifd/next'</span><span class=\"token punctuation\">;</span>\n<span class=\"token keyword\">import</span> moment <span class=\"token keyword\">from</span> <span class=\"token string\">'moment'</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">const</span> currentDate <span class=\"token operator\">=</span> <span class=\"token function\">moment</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n<span class=\"token keyword\">const</span> localeData <span class=\"token operator\">=</span> currentDate<span class=\"token punctuation\">.</span><span class=\"token function\">clone</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">.</span><span class=\"token function\">localeData</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n<span class=\"token keyword\">const</span> monthLocale <span class=\"token operator\">=</span> localeData<span class=\"token punctuation\">.</span><span class=\"token function\">monthsShort</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n\n\n<span class=\"token keyword\">function</span> <span class=\"token function\">dateCellRender</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">date</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token keyword\">const</span> dateNum <span class=\"token operator\">=</span> date<span class=\"token punctuation\">.</span><span class=\"token function\">date</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token keyword\">if</span> <span class=\"token punctuation\">(</span>currentDate<span class=\"token punctuation\">.</span><span class=\"token function\">month</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">!==</span> date<span class=\"token punctuation\">.</span><span class=\"token function\">month</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">return</span> dateNum<span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token keyword\">let</span> eventList<span class=\"token punctuation\">;</span>\n    <span class=\"token keyword\">switch</span> <span class=\"token punctuation\">(</span>dateNum<span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">case</span> <span class=\"token number\">1</span><span class=\"token punctuation\">:</span>\n            eventList <span class=\"token operator\">=</span> <span class=\"token punctuation\">[</span>\n                <span class=\"token punctuation\">{</span> type<span class=\"token punctuation\">:</span> <span class=\"token string\">'primary'</span><span class=\"token punctuation\">,</span> content<span class=\"token punctuation\">:</span> <span class=\"token string\">'Event 1'</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n                <span class=\"token punctuation\">{</span> type<span class=\"token punctuation\">:</span> <span class=\"token string\">'normal'</span><span class=\"token punctuation\">,</span> content<span class=\"token punctuation\">:</span> <span class=\"token string\">'Event 2'</span> <span class=\"token punctuation\">}</span>\n            <span class=\"token punctuation\">]</span><span class=\"token punctuation\">;</span>\n            <span class=\"token keyword\">break</span><span class=\"token punctuation\">;</span>\n        <span class=\"token keyword\">case</span> <span class=\"token number\">10</span><span class=\"token punctuation\">:</span>\n            eventList <span class=\"token operator\">=</span> <span class=\"token punctuation\">[</span>\n                <span class=\"token punctuation\">{</span> type<span class=\"token punctuation\">:</span> <span class=\"token string\">'normal'</span><span class=\"token punctuation\">,</span> content<span class=\"token punctuation\">:</span> <span class=\"token string\">'Event 3'</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n                <span class=\"token punctuation\">{</span> type<span class=\"token punctuation\">:</span> <span class=\"token string\">'normal'</span><span class=\"token punctuation\">,</span> content<span class=\"token punctuation\">:</span> <span class=\"token string\">'Event 4'</span> <span class=\"token punctuation\">}</span>\n            <span class=\"token punctuation\">]</span><span class=\"token punctuation\">;</span>\n            <span class=\"token keyword\">break</span><span class=\"token punctuation\">;</span>\n        <span class=\"token keyword\">case</span> <span class=\"token number\">11</span><span class=\"token punctuation\">:</span>\n            eventList <span class=\"token operator\">=</span> <span class=\"token punctuation\">[</span>\n                <span class=\"token punctuation\">{</span> type<span class=\"token punctuation\">:</span> <span class=\"token string\">'primary'</span><span class=\"token punctuation\">,</span> content<span class=\"token punctuation\">:</span> <span class=\"token string\">'Event 5'</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n                <span class=\"token punctuation\">{</span> type<span class=\"token punctuation\">:</span> <span class=\"token string\">'primary'</span><span class=\"token punctuation\">,</span> content<span class=\"token punctuation\">:</span> <span class=\"token string\">'Event 6'</span> <span class=\"token punctuation\">}</span>\n            <span class=\"token punctuation\">]</span><span class=\"token punctuation\">;</span>\n            <span class=\"token keyword\">break</span><span class=\"token punctuation\">;</span>\n        <span class=\"token keyword\">default</span><span class=\"token punctuation\">:</span>\n            eventList <span class=\"token operator\">=</span> <span class=\"token punctuation\">[</span><span class=\"token punctuation\">]</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token keyword\">return</span> <span class=\"token punctuation\">(</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span> <span class=\"token attr-name\">className</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>custom-calendar-cell<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span> <span class=\"token attr-name\">className</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>custom-calendar-cell-value<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">{</span>dateNum<span class=\"token punctuation\">}</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span> <span class=\"token attr-name\">className</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>custom-calendar-cell-content<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>ul</span> <span class=\"token attr-name\">className</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>event-list<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                </span><span class=\"token punctuation\">{</span>eventList<span class=\"token punctuation\">.</span><span class=\"token function\">map</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">item<span class=\"token punctuation\">,</span> key</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>li</span> <span class=\"token attr-name\">className</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token template-string\"><span class=\"token template-punctuation string\">`</span><span class=\"token interpolation\"><span class=\"token interpolation-punctuation punctuation\">${</span>item<span class=\"token punctuation\">.</span>type<span class=\"token interpolation-punctuation punctuation\">}</span></span><span class=\"token string\">-event</span><span class=\"token template-punctuation string\">`</span></span><span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">key</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>key<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">{</span>item<span class=\"token punctuation\">.</span>content<span class=\"token punctuation\">}</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>li</span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">}</span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>ul</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span>\n\n<span class=\"token keyword\">function</span> <span class=\"token function\">monthCellRender</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">date</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token keyword\">if</span> <span class=\"token punctuation\">(</span>currentDate<span class=\"token punctuation\">.</span><span class=\"token function\">month</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">===</span> date<span class=\"token punctuation\">.</span><span class=\"token function\">month</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">return</span> <span class=\"token punctuation\">(</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">{</span>monthLocale<span class=\"token punctuation\">[</span>date<span class=\"token punctuation\">.</span><span class=\"token function\">month</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">]</span><span class=\"token punctuation\">}</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">Events</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n    <span class=\"token keyword\">return</span> monthLocale<span class=\"token punctuation\">[</span>date<span class=\"token punctuation\">.</span><span class=\"token function\">month</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">]</span><span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span>\n\nReactDOM<span class=\"token punctuation\">.</span><span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Calendar</span></span> <span class=\"token attr-name\">dateCellRender</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>dateCellRender<span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">monthCellRender</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>monthCellRender<span class=\"token punctuation\">}</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token punctuation\">,</span> mountNode<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span></code></pre></div><style type=\"text/css\">.custom-calendar-guide {\n    width: 270px;\n    border: 1px solid #C4C6CF;\n    border-radius: 3px;\n    overflow: hidden;\n    margin-top: 20px;\n}\n\n.custom-calendar-cell-content {\n    height: 50px;\n    text-align: left;\n}\n\n.event-list {\n    margin: 0;\n    padding: 0;\n    list-style: none;\n}\n\n.primary-event {\n    color: white;\n    background: red;\n    border-radius: 3px;\n    padding-left: 10px;\n    margin-bottom: 3px;\n}\n\n.normal-event {\n    color: white;\n    background: blue;\n    border-radius: 3px;\n    padding-left: 10px;\n    margin-bottom: 3px;\n}</style><div class=\"highlight\"><pre class=\"language-css\"><code class=\"language-css\"><span class=\"token selector\">.custom-calendar-guide</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token property\">width</span><span class=\"token punctuation\">:</span> 270px<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">border</span><span class=\"token punctuation\">:</span> 1px solid #C4C6CF<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">border-radius</span><span class=\"token punctuation\">:</span> 3px<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">overflow</span><span class=\"token punctuation\">:</span> hidden<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">margin-top</span><span class=\"token punctuation\">:</span> 20px<span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span>\n\n<span class=\"token selector\">.custom-calendar-cell-content</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token property\">height</span><span class=\"token punctuation\">:</span> 50px<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">text-align</span><span class=\"token punctuation\">:</span> left<span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span>\n\n<span class=\"token selector\">.event-list</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token property\">margin</span><span class=\"token punctuation\">:</span> 0<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">padding</span><span class=\"token punctuation\">:</span> 0<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">list-style</span><span class=\"token punctuation\">:</span> none<span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span>\n\n<span class=\"token selector\">.primary-event</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token property\">color</span><span class=\"token punctuation\">:</span> white<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">background</span><span class=\"token punctuation\">:</span> red<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">border-radius</span><span class=\"token punctuation\">:</span> 3px<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">padding-left</span><span class=\"token punctuation\">:</span> 10px<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">margin-bottom</span><span class=\"token punctuation\">:</span> 3px<span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span>\n\n<span class=\"token selector\">.normal-event</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token property\">color</span><span class=\"token punctuation\">:</span> white<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">background</span><span class=\"token punctuation\">:</span> blue<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">border-radius</span><span class=\"token punctuation\">:</span> 3px<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">padding-left</span><span class=\"token punctuation\">:</span> 10px<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">margin-bottom</span><span class=\"token punctuation\">:</span> 3px<span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span></code></pre></div>"}