{"title":"Components that support internationalization","meta":{"title":"Components that support internationalization","description":"\n<p>Show the components that support internationalization in the current Next components.</p>\n","order":"2"},"codes":{"jsx":"import { ConfigProvider, Button, Radio, Calendar, Card, DatePicker, Dialog, Pagination, TimePicker, Timeline, Transfer, Select, Upload, Table } from '@alifd/next';\n\nimport enUS from '@alifd/next/lib/locale/en-us';\nimport zhCN from '@alifd/next/lib/locale/zh-cn';\n\n// If the application directly imports the next-with-locales.js file from cdn\n// it need to import locale file in the following way\n// import { locales } from '@alifd/next';\n// const enUS = locales['en-us'];\n// const zhCN = locales['zh-cn'];\n\nconst RangePicker = DatePicker.RangePicker;\n\nconst transferDataSource = (() => {\n    const dataSource = [];\n\n    for (let i = 0; i < 10; i++) {\n        dataSource.push({\n            label: `content ${i}`,\n            value: `${i}`,\n            disabled: i % 4 === 0\n        });\n    }\n\n    return dataSource;\n})();\n\nclass Demo extends React.Component {\n    constructor(props) {\n        super(props);\n\n        this.state = {\n            lang: 'en-us'\n        };\n\n        this.changeLang = this.changeLang.bind(this);\n        this.showDialog = this.showDialog.bind(this);\n    }\n\n    changeLang(lang) {\n        this.setState({\n            lang\n        });\n    }\n\n    showDialog() {\n        Dialog.confirm({\n            title: 'Confirm',\n            content: 'Are you sure you want to delete all alert e-mails waiting in queue?'\n        });\n    }\n\n    render() {\n        const locale = this.state.lang === 'en-us' ? enUS : zhCN;\n\n        return (\n            <div>\n                <div className=\"change-locale\">\n                    <span style={{ marginRight: 16 }}>Change locale of components: </span>\n                    <Radio.Group shape=\"button\" size=\"large\" defaultValue=\"en-us\" onChange={this.changeLang}>\n                        <Radio key=\"en\" value=\"en-us\">English</Radio>\n                        <Radio key=\"cn\" value=\"zh-cn\">中文</Radio>\n                    </Radio.Group>\n                </div>\n                <ConfigProvider locale={locale}>\n                    <div className=\"locale-components\">\n                        <Button type=\"primary\" onClick={this.showDialog}>Show Dialog</Button>\n                        <Select style={{ width: '150px' }} dataSource={['hello', 'bye']} />\n                        <DatePicker />\n                        <TimePicker />\n                        <RangePicker />\n                        <Calendar style={{ width: '350px', padding: '12px', border: '1px solid #C4C6CF', borderRadius: '3px' }} shape=\"card\" />\n                        <Pagination defaultCurrent={2} />\n                        <Transfer dataSource={transferDataSource} defaultValue={['3']} defaultLeftChecked={['1']} titles={['Source', 'Target']} />\n                        <Table style={{ width: '500px' }} dataSource={[]}>\n                            <Table.Column title=\"Name\" dataIndex=\"name\" filters={[{ label: 'Filter 1', value: '1' }, { label: 'Filter 2', value: '2' }]} />\n                            <Table.Column title=\"Age\" dataIndex=\"age\" />\n                        </Table>\n                        <Card style={{ width: '300px' }} title=\"Title\">\n                            <div style={{ height: '250px', background: '#F7F8FA' }}></div>\n                        </Card>\n                        <Timeline fold={[{foldArea: [1, 2], foldShow: true}]}>\n                            <Timeline.Item title=\"Signed\" content=\"Signed, sign Alibaba is a small post office, thanks to the use of STO, look forward to once again at your service\" time={'2016-06-10 10:30:00'} state=\"process\"/>\n                            <Timeline.Item title=\"Ship\" content=\"Express has arrived in Hangzhou, Zhejiang Binjiang company\" time={'2016-06-10 09:30:00'} />\n                            <Timeline.Item title=\"Ship\" content=\"Zhejiang Hangzhou Riverside company sent a member for you to send pieces\" time={'2016-06-10 09:03:00'} />\n                            <Timeline.Item title=\"Ship\" content=\"Zhejiang Hangzhou Transshipment Center has been issued\" time={'2016-06-10 06:10:00'} />\n                        </Timeline>\n                        <Upload.Dragger style={{ width: '500px' }}\n                            listType=\"image\"\n                            action=\"https://www.easy-mock.com/mock/5b713974309d0d7d107a74a3/alifd/upload\"\n                            accept=\"image/png, image/jpg, image/jpeg, image/gif, image/bmp\" />\n                    </div>\n                </ConfigProvider>\n            </div>\n        );\n    }\n}\n\nReactDOM.render(<Demo />, mountNode);\n","css":".change-locale {\n    border-bottom: 1px solid #d9d9d9;\n    padding-bottom: 16px;\n}\n\n.locale-components > * {\n    margin: 16px 0;\n    display: block;\n}\n"},"body":"\n````jsx\nimport { ConfigProvider, Button, Radio, Calendar, Card, DatePicker, Dialog, Pagination, TimePicker, Timeline, Transfer, Select, Upload, Table } from '@alifd/next';\n\nimport enUS from '@alifd/next/lib/locale/en-us';\nimport zhCN from '@alifd/next/lib/locale/zh-cn';\n\n// If the application directly imports the next-with-locales.js file from cdn\n// it need to import locale file in the following way\n// import { locales } from '@alifd/next';\n// const enUS = locales['en-us'];\n// const zhCN = locales['zh-cn'];\n\nconst RangePicker = DatePicker.RangePicker;\n\nconst transferDataSource = (() => {\n    const dataSource = [];\n\n    for (let i = 0; i < 10; i++) {\n        dataSource.push({\n            label: `content ${i}`,\n            value: `${i}`,\n            disabled: i % 4 === 0\n        });\n    }\n\n    return dataSource;\n})();\n\nclass Demo extends React.Component {\n    constructor(props) {\n        super(props);\n\n        this.state = {\n            lang: 'en-us'\n        };\n\n        this.changeLang = this.changeLang.bind(this);\n        this.showDialog = this.showDialog.bind(this);\n    }\n\n    changeLang(lang) {\n        this.setState({\n            lang\n        });\n    }\n\n    showDialog() {\n        Dialog.confirm({\n            title: 'Confirm',\n            content: 'Are you sure you want to delete all alert e-mails waiting in queue?'\n        });\n    }\n\n    render() {\n        const locale = this.state.lang === 'en-us' ? enUS : zhCN;\n\n        return (\n            <div>\n                <div className=\"change-locale\">\n                    <span style={{ marginRight: 16 }}>Change locale of components: </span>\n                    <Radio.Group shape=\"button\" size=\"large\" defaultValue=\"en-us\" onChange={this.changeLang}>\n                        <Radio key=\"en\" value=\"en-us\">English</Radio>\n                        <Radio key=\"cn\" value=\"zh-cn\">中文</Radio>\n                    </Radio.Group>\n                </div>\n                <ConfigProvider locale={locale}>\n                    <div className=\"locale-components\">\n                        <Button type=\"primary\" onClick={this.showDialog}>Show Dialog</Button>\n                        <Select style={{ width: '150px' }} dataSource={['hello', 'bye']} />\n                        <DatePicker />\n                        <TimePicker />\n                        <RangePicker />\n                        <Calendar style={{ width: '350px', padding: '12px', border: '1px solid #C4C6CF', borderRadius: '3px' }} shape=\"card\" />\n                        <Pagination defaultCurrent={2} />\n                        <Transfer dataSource={transferDataSource} defaultValue={['3']} defaultLeftChecked={['1']} titles={['Source', 'Target']} />\n                        <Table style={{ width: '500px' }} dataSource={[]}>\n                            <Table.Column title=\"Name\" dataIndex=\"name\" filters={[{ label: 'Filter 1', value: '1' }, { label: 'Filter 2', value: '2' }]} />\n                            <Table.Column title=\"Age\" dataIndex=\"age\" />\n                        </Table>\n                        <Card style={{ width: '300px' }} title=\"Title\">\n                            <div style={{ height: '250px', background: '#F7F8FA' }}></div>\n                        </Card>\n                        <Timeline fold={[{foldArea: [1, 2], foldShow: true}]}>\n                            <Timeline.Item title=\"Signed\" content=\"Signed, sign Alibaba is a small post office, thanks to the use of STO, look forward to once again at your service\" time={'2016-06-10 10:30:00'} state=\"process\"/>\n                            <Timeline.Item title=\"Ship\" content=\"Express has arrived in Hangzhou, Zhejiang Binjiang company\" time={'2016-06-10 09:30:00'} />\n                            <Timeline.Item title=\"Ship\" content=\"Zhejiang Hangzhou Riverside company sent a member for you to send pieces\" time={'2016-06-10 09:03:00'} />\n                            <Timeline.Item title=\"Ship\" content=\"Zhejiang Hangzhou Transshipment Center has been issued\" time={'2016-06-10 06:10:00'} />\n                        </Timeline>\n                        <Upload.Dragger style={{ width: '500px' }}\n                            listType=\"image\"\n                            action=\"https://www.easy-mock.com/mock/5b713974309d0d7d107a74a3/alifd/upload\"\n                            accept=\"image/png, image/jpg, image/jpeg, image/gif, image/bmp\" />\n                    </div>\n                </ConfigProvider>\n            </div>\n        );\n    }\n}\n\nReactDOM.render(<Demo />, mountNode);\n````\n\n```` css\n.change-locale {\n    border-bottom: 1px solid #d9d9d9;\n    padding-bottom: 16px;\n}\n\n.locale-components > * {\n    margin: 16px 0;\n    display: block;\n}\n````","html":"<script>(function(){'use strict';\n\nvar _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if (\"value\" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();\n\nvar _next = require('@alifd/next');\n\nvar _enUs = require('@alifd/next/lib/locale/en-us');\n\nvar _enUs2 = _interopRequireDefault(_enUs);\n\nvar _zhCn = require('@alifd/next/lib/locale/zh-cn');\n\nvar _zhCn2 = _interopRequireDefault(_zhCn);\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }\n\nfunction _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError(\"Cannot call a class as a function\"); } }\n\nfunction _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError(\"this hasn't been initialised - super() hasn't been called\"); } return call && (typeof call === \"object\" || typeof call === \"function\") ? call : self; }\n\nfunction _inherits(subClass, superClass) { if (typeof superClass !== \"function\" && superClass !== null) { throw new TypeError(\"Super expression must either be null or a function, not \" + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }\n\n// If the application directly imports the next-with-locales.js file from cdn\n// it need to import locale file in the following way\n// import { locales } from '@alifd/next';\n// const enUS = locales['en-us'];\n// const zhCN = locales['zh-cn'];\n\nvar RangePicker = _next.DatePicker.RangePicker;\n\nvar transferDataSource = function () {\n    var dataSource = [];\n\n    for (var i = 0; i < 10; i++) {\n        dataSource.push({\n            label: 'content ' + i,\n            value: '' + i,\n            disabled: i % 4 === 0\n        });\n    }\n\n    return dataSource;\n}();\n\nvar Demo = function (_React$Component) {\n    _inherits(Demo, _React$Component);\n\n    function Demo(props) {\n        _classCallCheck(this, Demo);\n\n        var _this = _possibleConstructorReturn(this, (Demo.__proto__ || Object.getPrototypeOf(Demo)).call(this, props));\n\n        _this.state = {\n            lang: 'en-us'\n        };\n\n        _this.changeLang = _this.changeLang.bind(_this);\n        _this.showDialog = _this.showDialog.bind(_this);\n        return _this;\n    }\n\n    _createClass(Demo, [{\n        key: 'changeLang',\n        value: function changeLang(lang) {\n            this.setState({\n                lang: lang\n            });\n        }\n    }, {\n        key: 'showDialog',\n        value: function showDialog() {\n            _next.Dialog.confirm({\n                title: 'Confirm',\n                content: 'Are you sure you want to delete all alert e-mails waiting in queue?'\n            });\n        }\n    }, {\n        key: 'render',\n        value: function render() {\n            var locale = this.state.lang === 'en-us' ? _enUs2.default : _zhCn2.default;\n\n            return React.createElement(\n                'div',\n                null,\n                React.createElement(\n                    'div',\n                    { className: 'change-locale' },\n                    React.createElement(\n                        'span',\n                        { style: { marginRight: 16 } },\n                        'Change locale of components: '\n                    ),\n                    React.createElement(\n                        _next.Radio.Group,\n                        { shape: 'button', size: 'large', defaultValue: 'en-us', onChange: this.changeLang },\n                        React.createElement(\n                            _next.Radio,\n                            { key: 'en', value: 'en-us' },\n                            'English'\n                        ),\n                        React.createElement(\n                            _next.Radio,\n                            { key: 'cn', value: 'zh-cn' },\n                            '\\u4E2D\\u6587'\n                        )\n                    )\n                ),\n                React.createElement(\n                    _next.ConfigProvider,\n                    { locale: locale },\n                    React.createElement(\n                        'div',\n                        { className: 'locale-components' },\n                        React.createElement(\n                            _next.Button,\n                            { type: 'primary', onClick: this.showDialog },\n                            'Show Dialog'\n                        ),\n                        React.createElement(_next.Select, { style: { width: '150px' }, dataSource: ['hello', 'bye'] }),\n                        React.createElement(_next.DatePicker, null),\n                        React.createElement(_next.TimePicker, null),\n                        React.createElement(RangePicker, null),\n                        React.createElement(_next.Calendar, { style: { width: '350px', padding: '12px', border: '1px solid #C4C6CF', borderRadius: '3px' }, shape: 'card' }),\n                        React.createElement(_next.Pagination, { defaultCurrent: 2 }),\n                        React.createElement(_next.Transfer, { dataSource: transferDataSource, defaultValue: ['3'], defaultLeftChecked: ['1'], titles: ['Source', 'Target'] }),\n                        React.createElement(\n                            _next.Table,\n                            { style: { width: '500px' }, dataSource: [] },\n                            React.createElement(_next.Table.Column, { title: 'Name', dataIndex: 'name', filters: [{ label: 'Filter 1', value: '1' }, { label: 'Filter 2', value: '2' }] }),\n                            React.createElement(_next.Table.Column, { title: 'Age', dataIndex: 'age' })\n                        ),\n                        React.createElement(\n                            _next.Card,\n                            { style: { width: '300px' }, title: 'Title' },\n                            React.createElement('div', { style: { height: '250px', background: '#F7F8FA' } })\n                        ),\n                        React.createElement(\n                            _next.Timeline,\n                            { fold: [{ foldArea: [1, 2], foldShow: true }] },\n                            React.createElement(_next.Timeline.Item, { title: 'Signed', content: 'Signed, sign Alibaba is a small post office, thanks to the use of STO, look forward to once again at your service', time: '2016-06-10 10:30:00', state: 'process' }),\n                            React.createElement(_next.Timeline.Item, { title: 'Ship', content: 'Express has arrived in Hangzhou, Zhejiang Binjiang company', time: '2016-06-10 09:30:00' }),\n                            React.createElement(_next.Timeline.Item, { title: 'Ship', content: 'Zhejiang Hangzhou Riverside company sent a member for you to send pieces', time: '2016-06-10 09:03:00' }),\n                            React.createElement(_next.Timeline.Item, { title: 'Ship', content: 'Zhejiang Hangzhou Transshipment Center has been issued', time: '2016-06-10 06:10:00' })\n                        ),\n                        React.createElement(_next.Upload.Dragger, { style: { width: '500px' },\n                            listType: 'image',\n                            action: 'https://www.easy-mock.com/mock/5b713974309d0d7d107a74a3/alifd/upload',\n                            accept: 'image/png, image/jpg, image/jpeg, image/gif, image/bmp' })\n                    )\n                )\n            );\n        }\n    }]);\n\n    return Demo;\n}(React.Component);\n\nReactDOM.render(React.createElement(Demo, null), mountNode);})()</script><div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\"><span class=\"token keyword\">import</span> <span class=\"token punctuation\">{</span> ConfigProvider<span class=\"token punctuation\">,</span> Button<span class=\"token punctuation\">,</span> Radio<span class=\"token punctuation\">,</span> Calendar<span class=\"token punctuation\">,</span> Card<span class=\"token punctuation\">,</span> DatePicker<span class=\"token punctuation\">,</span> Dialog<span class=\"token punctuation\">,</span> Pagination<span class=\"token punctuation\">,</span> TimePicker<span class=\"token punctuation\">,</span> Timeline<span class=\"token punctuation\">,</span> Transfer<span class=\"token punctuation\">,</span> Select<span class=\"token punctuation\">,</span> Upload<span class=\"token punctuation\">,</span> Table <span class=\"token punctuation\">}</span> <span class=\"token keyword\">from</span> <span class=\"token string\">'@alifd/next'</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">import</span> enUS <span class=\"token keyword\">from</span> <span class=\"token string\">'@alifd/next/lib/locale/en-us'</span><span class=\"token punctuation\">;</span>\n<span class=\"token keyword\">import</span> zhCN <span class=\"token keyword\">from</span> <span class=\"token string\">'@alifd/next/lib/locale/zh-cn'</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token comment\">// If the application directly imports the next-with-locales.js file from cdn</span>\n<span class=\"token comment\">// it need to import locale file in the following way</span>\n<span class=\"token comment\">// import { locales } from '@alifd/next';</span>\n<span class=\"token comment\">// const enUS = locales['en-us'];</span>\n<span class=\"token comment\">// const zhCN = locales['zh-cn'];</span>\n\n<span class=\"token keyword\">const</span> RangePicker <span class=\"token operator\">=</span> DatePicker<span class=\"token punctuation\">.</span>RangePicker<span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">const</span> transferDataSource <span class=\"token operator\">=</span> <span class=\"token punctuation\">(</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token punctuation\">{</span>\n    <span class=\"token keyword\">const</span> dataSource <span class=\"token operator\">=</span> <span class=\"token punctuation\">[</span><span class=\"token punctuation\">]</span><span class=\"token punctuation\">;</span>\n\n    <span class=\"token keyword\">for</span> <span class=\"token punctuation\">(</span><span class=\"token keyword\">let</span> i <span class=\"token operator\">=</span> <span class=\"token number\">0</span><span class=\"token punctuation\">;</span> i <span class=\"token operator\">&lt;</span> <span class=\"token number\">10</span><span class=\"token punctuation\">;</span> i<span class=\"token operator\">++</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        dataSource<span class=\"token punctuation\">.</span><span class=\"token function\">push</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span>\n            label<span class=\"token punctuation\">:</span> <span class=\"token template-string\"><span class=\"token template-punctuation string\">`</span><span class=\"token string\">content </span><span class=\"token interpolation\"><span class=\"token interpolation-punctuation punctuation\">${</span>i<span class=\"token interpolation-punctuation punctuation\">}</span></span><span class=\"token template-punctuation string\">`</span></span><span class=\"token punctuation\">,</span>\n            value<span class=\"token punctuation\">:</span> <span class=\"token template-string\"><span class=\"token template-punctuation string\">`</span><span class=\"token interpolation\"><span class=\"token interpolation-punctuation punctuation\">${</span>i<span class=\"token interpolation-punctuation punctuation\">}</span></span><span class=\"token template-punctuation string\">`</span></span><span class=\"token punctuation\">,</span>\n            disabled<span class=\"token punctuation\">:</span> i <span class=\"token operator\">%</span> <span class=\"token number\">4</span> <span class=\"token operator\">===</span> <span class=\"token number\">0</span>\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token keyword\">return</span> dataSource<span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">class</span> <span class=\"token class-name\">Demo</span> <span class=\"token keyword\">extends</span> <span class=\"token class-name\">React<span class=\"token punctuation\">.</span>Component</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token function\">constructor</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">props</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">super</span><span class=\"token punctuation\">(</span>props<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>state <span class=\"token operator\">=</span> <span class=\"token punctuation\">{</span>\n            lang<span class=\"token punctuation\">:</span> <span class=\"token string\">'en-us'</span>\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>changeLang <span class=\"token operator\">=</span> <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">changeLang</span><span class=\"token punctuation\">.</span><span class=\"token function\">bind</span><span class=\"token punctuation\">(</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>showDialog <span class=\"token operator\">=</span> <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">showDialog</span><span class=\"token punctuation\">.</span><span class=\"token function\">bind</span><span class=\"token punctuation\">(</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token function\">changeLang</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">lang</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">setState</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span>\n            lang\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token function\">showDialog</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        Dialog<span class=\"token punctuation\">.</span><span class=\"token function\">confirm</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span>\n            title<span class=\"token punctuation\">:</span> <span class=\"token string\">'Confirm'</span><span class=\"token punctuation\">,</span>\n            content<span class=\"token punctuation\">:</span> <span class=\"token string\">'Are you sure you want to delete all alert e-mails waiting in queue?'</span>\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">const</span> locale <span class=\"token operator\">=</span> <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>state<span class=\"token punctuation\">.</span>lang <span class=\"token operator\">===</span> <span class=\"token string\">'en-us'</span> <span class=\"token operator\">?</span> enUS <span class=\"token punctuation\">:</span> zhCN<span class=\"token punctuation\">;</span>\n\n        <span class=\"token keyword\">return</span> <span class=\"token punctuation\">(</span>\n            <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span> <span class=\"token attr-name\">className</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>change-locale<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>span</span> <span class=\"token attr-name\">style</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token punctuation\">{</span> marginRight<span class=\"token punctuation\">:</span> <span class=\"token number\">16</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">Change locale of components: </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>span</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Radio.Group</span></span> <span class=\"token attr-name\">shape</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>button<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">size</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>large<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">defaultValue</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>en-us<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">onChange</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>changeLang<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Radio</span></span> <span class=\"token attr-name\">key</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>en<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">value</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>en-us<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">English</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Radio</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Radio</span></span> <span class=\"token attr-name\">key</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>cn<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">value</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>zh-cn<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">中文</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Radio</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Radio.Group</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">ConfigProvider</span></span> <span class=\"token attr-name\">locale</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>locale<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span> <span class=\"token attr-name\">className</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>locale-components<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Button</span></span> <span class=\"token attr-name\">type</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>primary<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">onClick</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>showDialog<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">Show Dialog</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Button</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Select</span></span> <span class=\"token attr-name\">style</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token punctuation\">{</span> width<span class=\"token punctuation\">:</span> <span class=\"token string\">'150px'</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">dataSource</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token punctuation\">[</span><span class=\"token string\">'hello'</span><span class=\"token punctuation\">,</span> <span class=\"token string\">'bye'</span><span class=\"token punctuation\">]</span><span class=\"token punctuation\">}</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">DatePicker</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">TimePicker</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">RangePicker</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Calendar</span></span> <span class=\"token attr-name\">style</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token punctuation\">{</span> width<span class=\"token punctuation\">:</span> <span class=\"token string\">'350px'</span><span class=\"token punctuation\">,</span> padding<span class=\"token punctuation\">:</span> <span class=\"token string\">'12px'</span><span class=\"token punctuation\">,</span> border<span class=\"token punctuation\">:</span> <span class=\"token string\">'1px solid #C4C6CF'</span><span class=\"token punctuation\">,</span> borderRadius<span class=\"token punctuation\">:</span> <span class=\"token string\">'3px'</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">shape</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>card<span class=\"token punctuation\">\"</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Pagination</span></span> <span class=\"token attr-name\">defaultCurrent</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token number\">2</span><span class=\"token punctuation\">}</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Transfer</span></span> <span class=\"token attr-name\">dataSource</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>transferDataSource<span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">defaultValue</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token punctuation\">[</span><span class=\"token string\">'3'</span><span class=\"token punctuation\">]</span><span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">defaultLeftChecked</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token punctuation\">[</span><span class=\"token string\">'1'</span><span class=\"token punctuation\">]</span><span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">titles</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token punctuation\">[</span><span class=\"token string\">'Source'</span><span class=\"token punctuation\">,</span> <span class=\"token string\">'Target'</span><span class=\"token punctuation\">]</span><span class=\"token punctuation\">}</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Table</span></span> <span class=\"token attr-name\">style</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token punctuation\">{</span> width<span class=\"token punctuation\">:</span> <span class=\"token string\">'500px'</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">dataSource</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token punctuation\">[</span><span class=\"token punctuation\">]</span><span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Table.Column</span></span> <span class=\"token attr-name\">title</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>Name<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">dataIndex</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>name<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">filters</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token punctuation\">[</span><span class=\"token punctuation\">{</span> label<span class=\"token punctuation\">:</span> <span class=\"token string\">'Filter 1'</span><span class=\"token punctuation\">,</span> value<span class=\"token punctuation\">:</span> <span class=\"token string\">'1'</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span> <span class=\"token punctuation\">{</span> label<span class=\"token punctuation\">:</span> <span class=\"token string\">'Filter 2'</span><span class=\"token punctuation\">,</span> value<span class=\"token punctuation\">:</span> <span class=\"token string\">'2'</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">]</span><span class=\"token punctuation\">}</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Table.Column</span></span> <span class=\"token attr-name\">title</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>Age<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">dataIndex</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>age<span class=\"token punctuation\">\"</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Table</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Card</span></span> <span class=\"token attr-name\">style</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token punctuation\">{</span> width<span class=\"token punctuation\">:</span> <span class=\"token string\">'300px'</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">title</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>Title<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span> <span class=\"token attr-name\">style</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token punctuation\">{</span> height<span class=\"token punctuation\">:</span> <span class=\"token string\">'250px'</span><span class=\"token punctuation\">,</span> background<span class=\"token punctuation\">:</span> <span class=\"token string\">'#F7F8FA'</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Card</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Timeline</span></span> <span class=\"token attr-name\">fold</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token punctuation\">[</span><span class=\"token punctuation\">{</span>foldArea<span class=\"token punctuation\">:</span> <span class=\"token punctuation\">[</span><span class=\"token number\">1</span><span class=\"token punctuation\">,</span> <span class=\"token number\">2</span><span class=\"token punctuation\">]</span><span class=\"token punctuation\">,</span> foldShow<span class=\"token punctuation\">:</span> <span class=\"token boolean\">true</span><span class=\"token punctuation\">}</span><span class=\"token punctuation\">]</span><span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Timeline.Item</span></span> <span class=\"token attr-name\">title</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>Signed<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">content</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>Signed, sign Alibaba is a small post office, thanks to the use of STO, look forward to once again at your service<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">time</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token string\">'2016-06-10 10:30:00'</span><span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">state</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>process<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Timeline.Item</span></span> <span class=\"token attr-name\">title</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>Ship<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">content</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>Express has arrived in Hangzhou, Zhejiang Binjiang company<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">time</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token string\">'2016-06-10 09:30:00'</span><span class=\"token punctuation\">}</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Timeline.Item</span></span> <span class=\"token attr-name\">title</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>Ship<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">content</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>Zhejiang Hangzhou Riverside company sent a member for you to send pieces<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">time</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token string\">'2016-06-10 09:03:00'</span><span class=\"token punctuation\">}</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Timeline.Item</span></span> <span class=\"token attr-name\">title</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>Ship<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">content</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>Zhejiang Hangzhou Transshipment Center has been issued<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">time</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token string\">'2016-06-10 06:10:00'</span><span class=\"token punctuation\">}</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Timeline</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Upload.Dragger</span></span> <span class=\"token attr-name\">style</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token punctuation\">{</span> width<span class=\"token punctuation\">:</span> <span class=\"token string\">'500px'</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">}</span></span>\n                            <span class=\"token attr-name\">listType</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>image<span class=\"token punctuation\">\"</span></span>\n                            <span class=\"token attr-name\">action</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>https://www.easy-mock.com/mock/5b713974309d0d7d107a74a3/alifd/upload<span class=\"token punctuation\">\"</span></span>\n                            <span class=\"token attr-name\">accept</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>image/png, image/jpg, image/jpeg, image/gif, image/bmp<span class=\"token punctuation\">\"</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">ConfigProvider</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span>\n        <span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n<span class=\"token punctuation\">}</span>\n\nReactDOM<span class=\"token punctuation\">.</span><span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Demo</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token punctuation\">,</span> mountNode<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span></code></pre></div><style type=\"text/css\">.change-locale {\n    border-bottom: 1px solid #d9d9d9;\n    padding-bottom: 16px;\n}\n\n.locale-components > * {\n    margin: 16px 0;\n    display: block;\n}</style><div class=\"highlight\"><pre class=\"language-css\"><code class=\"language-css\"><span class=\"token selector\">.change-locale</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token property\">border-bottom</span><span class=\"token punctuation\">:</span> 1px solid #d9d9d9<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">padding-bottom</span><span class=\"token punctuation\">:</span> 16px<span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span>\n\n<span class=\"token selector\">.locale-components > *</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token property\">margin</span><span class=\"token punctuation\">:</span> 16px 0<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">display</span><span class=\"token punctuation\">:</span> block<span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span></code></pre></div>"}