{"title":"Hooks","meta":{"title":"Hooks","description":"\n<p><code>Field</code> exposes a React Hook <code>useField</code> as a static method. Takes in the <code>options</code> parameter used with <code>new Field(...)</code>. <code>dependencies: react@^16.8</code></p>\n","order":"12"},"codes":{"jsx":"import ReactDOM from 'react-dom';\nimport React from 'react';\nimport { Input, Button, Field } from '@alifd/next';\n\n \nfunction App() {\n    const field = Field.useField();\n\n    const { init, setValue, reset, getError } = field;\n\n    function onGetValue() {\n        console.log(field.getValue('input'));\n    }\n\n    function onSetValue() {\n        field.setValue('input', 'xyz');\n    }\n\n    return (<div className=\"demo\">\n            <Input {...init('input', {\n                initValue: 'test',  \n                rules: [{\n                    required: true,\n                    pattern: /hello/,\n                    message: 'must be hello'\n                }]\n            })} />\n            <span style={{color: 'red'}}>{getError('input')}</span>\n\n            <br/><br/>\n            <Button onClick={onSetValue}> setValue </Button>\n            <Button onClick={onGetValue}> getValue </Button>\n            <br/><br/>\n        </div>);\n}\n \n \nReactDOM.render(<App/>, mountNode);\n \n "},"body":"\n````jsx\nimport ReactDOM from 'react-dom';\nimport React from 'react';\nimport { Input, Button, Field } from '@alifd/next';\n\n \nfunction App() {\n    const field = Field.useField();\n\n    const { init, setValue, reset, getError } = field;\n\n    function onGetValue() {\n        console.log(field.getValue('input'));\n    }\n\n    function onSetValue() {\n        field.setValue('input', 'xyz');\n    }\n\n    return (<div className=\"demo\">\n            <Input {...init('input', {\n                initValue: 'test',  \n                rules: [{\n                    required: true,\n                    pattern: /hello/,\n                    message: 'must be hello'\n                }]\n            })} />\n            <span style={{color: 'red'}}>{getError('input')}</span>\n\n            <br/><br/>\n            <Button onClick={onSetValue}> setValue </Button>\n            <Button onClick={onGetValue}> getValue </Button>\n            <br/><br/>\n        </div>);\n}\n \n \nReactDOM.render(<App/>, mountNode);\n \n ````","html":"<script>(function(){'use strict';\n\nvar _reactDom = require('react-dom');\n\nvar _reactDom2 = _interopRequireDefault(_reactDom);\n\nvar _react = require('react');\n\nvar _react2 = _interopRequireDefault(_react);\n\nvar _next = require('@alifd/next');\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }\n\nfunction App() {\n    var field = _next.Field.useField();\n\n    var init = field.init,\n        setValue = field.setValue,\n        reset = field.reset,\n        getError = field.getError;\n\n\n    function onGetValue() {\n        console.log(field.getValue('input'));\n    }\n\n    function onSetValue() {\n        field.setValue('input', 'xyz');\n    }\n\n    return _react2.default.createElement(\n        'div',\n        { className: 'demo' },\n        _react2.default.createElement(_next.Input, init('input', {\n            initValue: 'test',\n            rules: [{\n                required: true,\n                pattern: /hello/,\n                message: 'must be hello'\n            }]\n        })),\n        _react2.default.createElement(\n            'span',\n            { style: { color: 'red' } },\n            getError('input')\n        ),\n        _react2.default.createElement('br', null),\n        _react2.default.createElement('br', null),\n        _react2.default.createElement(\n            _next.Button,\n            { onClick: onSetValue },\n            ' setValue '\n        ),\n        _react2.default.createElement(\n            _next.Button,\n            { onClick: onGetValue },\n            ' getValue '\n        ),\n        _react2.default.createElement('br', null),\n        _react2.default.createElement('br', null)\n    );\n}\n\n_reactDom2.default.render(_react2.default.createElement(App, null), mountNode);})()</script><div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\"><span class=\"token keyword\">import</span> ReactDOM <span class=\"token keyword\">from</span> <span class=\"token string\">'react-dom'</span><span class=\"token punctuation\">;</span>\n<span class=\"token keyword\">import</span> React <span class=\"token keyword\">from</span> <span class=\"token string\">'react'</span><span class=\"token punctuation\">;</span>\n<span class=\"token keyword\">import</span> <span class=\"token punctuation\">{</span> Input<span class=\"token punctuation\">,</span> Button<span class=\"token punctuation\">,</span> Field <span class=\"token punctuation\">}</span> <span class=\"token keyword\">from</span> <span class=\"token string\">'@alifd/next'</span><span class=\"token punctuation\">;</span>\n\n\n<span class=\"token keyword\">function</span> <span class=\"token function\">App</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token keyword\">const</span> field <span class=\"token operator\">=</span> Field<span class=\"token punctuation\">.</span><span class=\"token function\">useField</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n\n    <span class=\"token keyword\">const</span> <span class=\"token punctuation\">{</span> init<span class=\"token punctuation\">,</span> setValue<span class=\"token punctuation\">,</span> reset<span class=\"token punctuation\">,</span> getError <span class=\"token punctuation\">}</span> <span class=\"token operator\">=</span> field<span class=\"token punctuation\">;</span>\n\n    <span class=\"token keyword\">function</span> <span class=\"token function\">onGetValue</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        console<span class=\"token punctuation\">.</span><span class=\"token function\">log</span><span class=\"token punctuation\">(</span>field<span class=\"token punctuation\">.</span><span class=\"token function\">getValue</span><span class=\"token punctuation\">(</span><span class=\"token string\">'input'</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token keyword\">function</span> <span class=\"token function\">onSetValue</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        field<span class=\"token punctuation\">.</span><span class=\"token function\">setValue</span><span class=\"token punctuation\">(</span><span class=\"token string\">'input'</span><span class=\"token punctuation\">,</span> <span class=\"token string\">'xyz'</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token keyword\">return</span> <span class=\"token punctuation\">(</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span> <span class=\"token attr-name\">className</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>demo<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n            &lt;Input </span><span class=\"token punctuation\">{</span><span class=\"token operator\">...</span><span class=\"token function\">init</span><span class=\"token punctuation\">(</span><span class=\"token string\">'input'</span><span class=\"token punctuation\">,</span> <span class=\"token punctuation\">{</span>\n                initValue<span class=\"token punctuation\">:</span> <span class=\"token string\">'test'</span><span class=\"token punctuation\">,</span>  \n                rules<span class=\"token punctuation\">:</span> <span class=\"token punctuation\">[</span><span class=\"token punctuation\">{</span>\n                    required<span class=\"token punctuation\">:</span> <span class=\"token boolean\">true</span><span class=\"token punctuation\">,</span>\n                    pattern<span class=\"token punctuation\">:</span> <span class=\"token regex\">/hello/</span><span class=\"token punctuation\">,</span>\n                    message<span class=\"token punctuation\">:</span> <span class=\"token string\">'must be hello'</span>\n                <span class=\"token punctuation\">}</span><span class=\"token punctuation\">]</span>\n            <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">}</span><span class=\"token plain-text\"> />\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>span</span> <span class=\"token attr-name\">style</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token punctuation\">{</span>color<span class=\"token punctuation\">:</span> <span class=\"token string\">'red'</span><span class=\"token punctuation\">}</span><span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">{</span><span class=\"token function\">getError</span><span class=\"token punctuation\">(</span><span class=\"token string\">'input'</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">}</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>span</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>br</span><span class=\"token punctuation\">/></span></span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>br</span><span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Button</span></span> <span class=\"token attr-name\">onClick</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>onSetValue<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\"> setValue </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Button</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Button</span></span> <span class=\"token attr-name\">onClick</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>onGetValue<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\"> getValue </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Button</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>br</span><span class=\"token punctuation\">/></span></span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>br</span><span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span>\n\n\nReactDOM<span class=\"token punctuation\">.</span><span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">App</span></span><span class=\"token punctuation\">/></span></span><span class=\"token punctuation\">,</span> mountNode<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n</code></pre></div>"}