{"title":"Set the width of the row","meta":{"title":"Set the width of the row","description":"\n<p>The default width of the <code>Row</code> is set to 100%. You can set the <code>fixed</code> property to true so that the width of <code>Row</code> does not immediately change with the size of the viewport. Instead, it is maintained at a certain breakpoint. You can also set the <code>fixedWidth</code> property to a certain breakpoint value, thus fixing the width of <code>Row</code>, no longer changing with the size of the viewport.</p>\n","order":"7"},"codes":{"jsx":"import { Grid } from '@alifd/next';\n\nconst { Row, Col } = Grid;\n\nconst breakpoints = {\n    xxs: 320,\n    xs: 480,\n    s: 720,\n    m: 990,\n    l: 1200,\n    xl: 1500\n};\n\nclass Demo extends React.Component {\n    componentDidMount() {\n        const row = ReactDOM.findDOMNode(this.refs.fixCol);\n\n        this.handleResize = () => {\n            let point = '';\n            const innerWidth = window.innerWidth || document.documentElement.clientWidth || document.body.clientWidth;\n            const keys = Object.keys(breakpoints);\n            for (let i = 0; i < keys.length; i++) {\n                const width = breakpoints[keys[i]];\n                const nextWidth = breakpoints[keys[i + 1]];\n                if (innerWidth > width && (innerWidth < nextWidth || !nextWidth)) {\n                    point = keys[i];\n                    break;\n                }\n            }\n\n            if (point) {\n                row.innerHTML = `${breakpoints[point]}px`;\n            }\n        };\n        window.addEventListener('resize', this.handleResize);\n\n        this.handleResize();\n    }\n\n    componentWillUnmount() {\n        window.removeListener('resize', this.handleResize);\n    }\n\n    render() {\n        return (\n            <div className=\"type-demo\">\n                <div className=\"demo-title\">Default</div>\n                <Row>\n                    <Col>100%</Col>\n                </Row>\n                <div className=\"demo-title\">Set fixed to true</div>\n                <Row ref=\"fixedRow\" fixed>\n                    <Col ref=\"fixCol\" />\n                </Row>\n                <div className=\"demo-title\">Set fixedWidth to 's'</div>\n                <Row fixedWidth=\"s\">\n                    <Col>720px</Col>\n                </Row>\n            </div>\n        );\n    }\n}\n\nReactDOM.render(<Demo />, mountNode);\n","css":".type-demo .demo-title {\n    margin-left: 20px;\n}\n\n.type-demo .next-row {\n    margin: 10px 0;\n}\n\n.type-demo .next-col {\n    border:1px solid #CCC;\n    border-radius: 3px;\n    background-color:#ECECEC;\n    height: 30px;\n    line-height: 30px;\n    text-align: center;\n}\n"},"body":"\n````jsx\nimport { Grid } from '@alifd/next';\n\nconst { Row, Col } = Grid;\n\nconst breakpoints = {\n    xxs: 320,\n    xs: 480,\n    s: 720,\n    m: 990,\n    l: 1200,\n    xl: 1500\n};\n\nclass Demo extends React.Component {\n    componentDidMount() {\n        const row = ReactDOM.findDOMNode(this.refs.fixCol);\n\n        this.handleResize = () => {\n            let point = '';\n            const innerWidth = window.innerWidth || document.documentElement.clientWidth || document.body.clientWidth;\n            const keys = Object.keys(breakpoints);\n            for (let i = 0; i < keys.length; i++) {\n                const width = breakpoints[keys[i]];\n                const nextWidth = breakpoints[keys[i + 1]];\n                if (innerWidth > width && (innerWidth < nextWidth || !nextWidth)) {\n                    point = keys[i];\n                    break;\n                }\n            }\n\n            if (point) {\n                row.innerHTML = `${breakpoints[point]}px`;\n            }\n        };\n        window.addEventListener('resize', this.handleResize);\n\n        this.handleResize();\n    }\n\n    componentWillUnmount() {\n        window.removeListener('resize', this.handleResize);\n    }\n\n    render() {\n        return (\n            <div className=\"type-demo\">\n                <div className=\"demo-title\">Default</div>\n                <Row>\n                    <Col>100%</Col>\n                </Row>\n                <div className=\"demo-title\">Set fixed to true</div>\n                <Row ref=\"fixedRow\" fixed>\n                    <Col ref=\"fixCol\" />\n                </Row>\n                <div className=\"demo-title\">Set fixedWidth to 's'</div>\n                <Row fixedWidth=\"s\">\n                    <Col>720px</Col>\n                </Row>\n            </div>\n        );\n    }\n}\n\nReactDOM.render(<Demo />, mountNode);\n````\n\n````css\n.type-demo .demo-title {\n    margin-left: 20px;\n}\n\n.type-demo .next-row {\n    margin: 10px 0;\n}\n\n.type-demo .next-col {\n    border:1px solid #CCC;\n    border-radius: 3px;\n    background-color:#ECECEC;\n    height: 30px;\n    line-height: 30px;\n    text-align: center;\n}\n````","html":"<script>(function(){'use strict';\n\nvar _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if (\"value\" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();\n\nvar _next = require('@alifd/next');\n\nfunction _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError(\"Cannot call a class as a function\"); } }\n\nfunction _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError(\"this hasn't been initialised - super() hasn't been called\"); } return call && (typeof call === \"object\" || typeof call === \"function\") ? call : self; }\n\nfunction _inherits(subClass, superClass) { if (typeof superClass !== \"function\" && superClass !== null) { throw new TypeError(\"Super expression must either be null or a function, not \" + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }\n\nvar Row = _next.Grid.Row,\n    Col = _next.Grid.Col;\n\n\nvar breakpoints = {\n    xxs: 320,\n    xs: 480,\n    s: 720,\n    m: 990,\n    l: 1200,\n    xl: 1500\n};\n\nvar Demo = function (_React$Component) {\n    _inherits(Demo, _React$Component);\n\n    function Demo() {\n        _classCallCheck(this, Demo);\n\n        return _possibleConstructorReturn(this, (Demo.__proto__ || Object.getPrototypeOf(Demo)).apply(this, arguments));\n    }\n\n    _createClass(Demo, [{\n        key: 'componentDidMount',\n        value: function componentDidMount() {\n            var row = ReactDOM.findDOMNode(this.refs.fixCol);\n\n            this.handleResize = function () {\n                var point = '';\n                var innerWidth = window.innerWidth || document.documentElement.clientWidth || document.body.clientWidth;\n                var keys = Object.keys(breakpoints);\n                for (var i = 0; i < keys.length; i++) {\n                    var width = breakpoints[keys[i]];\n                    var nextWidth = breakpoints[keys[i + 1]];\n                    if (innerWidth > width && (innerWidth < nextWidth || !nextWidth)) {\n                        point = keys[i];\n                        break;\n                    }\n                }\n\n                if (point) {\n                    row.innerHTML = breakpoints[point] + 'px';\n                }\n            };\n            window.addEventListener('resize', this.handleResize);\n\n            this.handleResize();\n        }\n    }, {\n        key: 'componentWillUnmount',\n        value: function componentWillUnmount() {\n            window.removeListener('resize', this.handleResize);\n        }\n    }, {\n        key: 'render',\n        value: function render() {\n            return React.createElement(\n                'div',\n                { className: 'type-demo' },\n                React.createElement(\n                    'div',\n                    { className: 'demo-title' },\n                    'Default'\n                ),\n                React.createElement(\n                    Row,\n                    null,\n                    React.createElement(\n                        Col,\n                        null,\n                        '100%'\n                    )\n                ),\n                React.createElement(\n                    'div',\n                    { className: 'demo-title' },\n                    'Set fixed to true'\n                ),\n                React.createElement(\n                    Row,\n                    { ref: 'fixedRow', fixed: true },\n                    React.createElement(Col, { ref: 'fixCol' })\n                ),\n                React.createElement(\n                    'div',\n                    { className: 'demo-title' },\n                    'Set fixedWidth to \\'s\\''\n                ),\n                React.createElement(\n                    Row,\n                    { fixedWidth: 's' },\n                    React.createElement(\n                        Col,\n                        null,\n                        '720px'\n                    )\n                )\n            );\n        }\n    }]);\n\n    return Demo;\n}(React.Component);\n\nReactDOM.render(React.createElement(Demo, null), mountNode);})()</script><div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\"><span class=\"token keyword\">import</span> <span class=\"token punctuation\">{</span> Grid <span class=\"token punctuation\">}</span> <span class=\"token keyword\">from</span> <span class=\"token string\">'@alifd/next'</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">const</span> <span class=\"token punctuation\">{</span> Row<span class=\"token punctuation\">,</span> Col <span class=\"token punctuation\">}</span> <span class=\"token operator\">=</span> Grid<span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">const</span> breakpoints <span class=\"token operator\">=</span> <span class=\"token punctuation\">{</span>\n    xxs<span class=\"token punctuation\">:</span> <span class=\"token number\">320</span><span class=\"token punctuation\">,</span>\n    xs<span class=\"token punctuation\">:</span> <span class=\"token number\">480</span><span class=\"token punctuation\">,</span>\n    s<span class=\"token punctuation\">:</span> <span class=\"token number\">720</span><span class=\"token punctuation\">,</span>\n    m<span class=\"token punctuation\">:</span> <span class=\"token number\">990</span><span class=\"token punctuation\">,</span>\n    l<span class=\"token punctuation\">:</span> <span class=\"token number\">1200</span><span class=\"token punctuation\">,</span>\n    xl<span class=\"token punctuation\">:</span> <span class=\"token number\">1500</span>\n<span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">class</span> <span class=\"token class-name\">Demo</span> <span class=\"token keyword\">extends</span> <span class=\"token class-name\">React<span class=\"token punctuation\">.</span>Component</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token function\">componentDidMount</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">const</span> row <span class=\"token operator\">=</span> ReactDOM<span class=\"token punctuation\">.</span><span class=\"token function\">findDOMNode</span><span class=\"token punctuation\">(</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>refs<span class=\"token punctuation\">.</span>fixCol<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function-variable function\">handleResize</span> <span class=\"token operator\">=</span> <span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token punctuation\">{</span>\n            <span class=\"token keyword\">let</span> point <span class=\"token operator\">=</span> <span class=\"token string\">''</span><span class=\"token punctuation\">;</span>\n            <span class=\"token keyword\">const</span> innerWidth <span class=\"token operator\">=</span> window<span class=\"token punctuation\">.</span>innerWidth <span class=\"token operator\">||</span> document<span class=\"token punctuation\">.</span>documentElement<span class=\"token punctuation\">.</span>clientWidth <span class=\"token operator\">||</span> document<span class=\"token punctuation\">.</span>body<span class=\"token punctuation\">.</span>clientWidth<span class=\"token punctuation\">;</span>\n            <span class=\"token keyword\">const</span> keys <span class=\"token operator\">=</span> Object<span class=\"token punctuation\">.</span><span class=\"token function\">keys</span><span class=\"token punctuation\">(</span>breakpoints<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n            <span class=\"token keyword\">for</span> <span class=\"token punctuation\">(</span><span class=\"token keyword\">let</span> i <span class=\"token operator\">=</span> <span class=\"token number\">0</span><span class=\"token punctuation\">;</span> i <span class=\"token operator\">&lt;</span> keys<span class=\"token punctuation\">.</span>length<span class=\"token punctuation\">;</span> i<span class=\"token operator\">++</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n                <span class=\"token keyword\">const</span> width <span class=\"token operator\">=</span> breakpoints<span class=\"token punctuation\">[</span>keys<span class=\"token punctuation\">[</span>i<span class=\"token punctuation\">]</span><span class=\"token punctuation\">]</span><span class=\"token punctuation\">;</span>\n                <span class=\"token keyword\">const</span> nextWidth <span class=\"token operator\">=</span> breakpoints<span class=\"token punctuation\">[</span>keys<span class=\"token punctuation\">[</span>i <span class=\"token operator\">+</span> <span class=\"token number\">1</span><span class=\"token punctuation\">]</span><span class=\"token punctuation\">]</span><span class=\"token punctuation\">;</span>\n                <span class=\"token keyword\">if</span> <span class=\"token punctuation\">(</span>innerWidth <span class=\"token operator\">></span> width <span class=\"token operator\">&amp;&amp;</span> <span class=\"token punctuation\">(</span>innerWidth <span class=\"token operator\">&lt;</span> nextWidth <span class=\"token operator\">||</span> <span class=\"token operator\">!</span>nextWidth<span class=\"token punctuation\">)</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n                    point <span class=\"token operator\">=</span> keys<span class=\"token punctuation\">[</span>i<span class=\"token punctuation\">]</span><span class=\"token punctuation\">;</span>\n                    <span class=\"token keyword\">break</span><span class=\"token punctuation\">;</span>\n                <span class=\"token punctuation\">}</span>\n            <span class=\"token punctuation\">}</span>\n\n            <span class=\"token keyword\">if</span> <span class=\"token punctuation\">(</span>point<span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n                row<span class=\"token punctuation\">.</span>innerHTML <span class=\"token operator\">=</span> <span class=\"token template-string\"><span class=\"token template-punctuation string\">`</span><span class=\"token interpolation\"><span class=\"token interpolation-punctuation punctuation\">${</span>breakpoints<span class=\"token punctuation\">[</span>point<span class=\"token punctuation\">]</span><span class=\"token interpolation-punctuation punctuation\">}</span></span><span class=\"token string\">px</span><span class=\"token template-punctuation string\">`</span></span><span class=\"token punctuation\">;</span>\n            <span class=\"token punctuation\">}</span>\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n        window<span class=\"token punctuation\">.</span><span class=\"token function\">addEventListener</span><span class=\"token punctuation\">(</span><span class=\"token string\">'resize'</span><span class=\"token punctuation\">,</span> <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>handleResize<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">handleResize</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token function\">componentWillUnmount</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        window<span class=\"token punctuation\">.</span><span class=\"token function\">removeListener</span><span class=\"token punctuation\">(</span><span class=\"token string\">'resize'</span><span class=\"token punctuation\">,</span> <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>handleResize<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">return</span> <span class=\"token punctuation\">(</span>\n            <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span> <span class=\"token attr-name\">className</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>type-demo<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span> <span class=\"token attr-name\">className</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>demo-title<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">Default</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Row</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Col</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">100%</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Col</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Row</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span> <span class=\"token attr-name\">className</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>demo-title<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">Set fixed to true</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Row</span></span> <span class=\"token attr-name\">ref</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>fixedRow<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">fixed</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Col</span></span> <span class=\"token attr-name\">ref</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>fixCol<span class=\"token punctuation\">\"</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Row</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span> <span class=\"token attr-name\">className</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>demo-title<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">Set fixedWidth to 's'</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Row</span></span> <span class=\"token attr-name\">fixedWidth</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>s<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                    </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Col</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">720px</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Col</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">Row</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span>\n        <span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n<span class=\"token punctuation\">}</span>\n\nReactDOM<span class=\"token punctuation\">.</span><span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Demo</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token punctuation\">,</span> mountNode<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span></code></pre></div><style type=\"text/css\">.type-demo .demo-title {\n    margin-left: 20px;\n}\n\n.type-demo .next-row {\n    margin: 10px 0;\n}\n\n.type-demo .next-col {\n    border:1px solid #CCC;\n    border-radius: 3px;\n    background-color:#ECECEC;\n    height: 30px;\n    line-height: 30px;\n    text-align: center;\n}</style><div class=\"highlight\"><pre class=\"language-css\"><code class=\"language-css\"><span class=\"token selector\">.type-demo .demo-title</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token property\">margin-left</span><span class=\"token punctuation\">:</span> 20px<span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span>\n\n<span class=\"token selector\">.type-demo .next-row</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token property\">margin</span><span class=\"token punctuation\">:</span> 10px 0<span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span>\n\n<span class=\"token selector\">.type-demo .next-col</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token property\">border</span><span class=\"token punctuation\">:</span>1px solid #CCC<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">border-radius</span><span class=\"token punctuation\">:</span> 3px<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">background-color</span><span class=\"token punctuation\">:</span>#ECECEC<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">height</span><span class=\"token punctuation\">:</span> 30px<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">line-height</span><span class=\"token punctuation\">:</span> 30px<span class=\"token punctuation\">;</span>\n    <span class=\"token property\">text-align</span><span class=\"token punctuation\">:</span> center<span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span></code></pre></div>"}