{"title":"拖拽排序","meta":{"title":"拖拽排序","description":"\n<p>可拖拽的表格。拖拽功能的实现依赖react-dnd@7.x 及react-dnd-html5-backend@7.x， 它要求react react-dom 版本高于16.3.x</p>\n","order":"24"},"codes":{"jsx":"import { Table } from '@alifd/next';\nimport { DragDropContext, DragSource, DropTarget } from 'react-dnd';\nimport HTML5Backend from 'react-dnd-html5-backend';\nimport classnames from 'classnames';\n\nconst { SelectionRow } = Table;\n\nlet dragingIndex = -1;\n\nfunction MyRow (props) {\n    const {\n        isDragging,\n        isOver,\n        connectDragSource,\n        connectDropTarget,\n        moveRow,\n        className,\n        ...others\n    } = props;\n\n    const opacity = isDragging ? 0 : 1;\n    const style = { ...others.style, cursor: 'move' };\n\n    const cls = classnames({\n        [className]: className,\n        'drop-over-upward': isOver && others.index < dragingIndex,\n        'drop-over-downward': isOver && others.index > dragingIndex,\n    });\n\n    return (<SelectionRow {...others}\n        style={{ ...style, ...{ opacity } }}\n        className={cls}\n        wrapper={(row) => connectDragSource(connectDropTarget(row))} />);\n}\n\nconst NewRow = DropTarget(\n    'row',\n    {\n        drop(props, monitor) {\n            const dragIndex = monitor.getItem().index;\n            const hoverIndex = props.index;\n\n            if (dragIndex === hoverIndex) {\n                return;\n            }\n\n            props.moveRow(dragIndex, hoverIndex);\n            monitor.getItem().index = hoverIndex;\n        },\n    },\n    (connect, monitor) => ({\n        connectDropTarget: connect.dropTarget(),\n        isOver: monitor.isOver(),\n    }),\n)(\n    DragSource(\n        'row',\n        {\n            beginDrag: props => {\n                dragingIndex = props.index;\n                return {\n                    id: props.record[props.primaryKey],\n                    index: props.rowIndex,\n                };\n            },\n        },\n        (connect, monitor) => ({\n            connectDragSource: connect.dragSource(),\n            isDragging: monitor.isDragging(),\n        }),\n    )(MyRow),\n);\n\nclass InnerTable extends React.Component {\n\n  constructor(props) {\n    super(props);\n    this.state = {\n      dataSource: [...props.dataSource],\n    };\n  }\n\n  componentWillReceiveProps(nextProps) {\n    if (nextProps.dataSource && JSON.stringify(nextProps.dataSource) !==\n      JSON.stringify(this.state.dataSource)) {\n      this.setState({ dataSource: [...nextProps.dataSource] });\n    }\n  }\n\n  moveRow = (dragIndex, hoverIndex) => {\n    const { onSort } = this.props;\n    const dragRow = this.state.dataSource[dragIndex];\n    const dataSource = [...this.state.dataSource];\n    dataSource.splice(dragIndex, 1);\n    dataSource.splice(hoverIndex, 0, dragRow);\n    this.setState({\n      dataSource,\n    });\n\n    onSort && onSort(this.state.dataSource);\n  };\n\n  render() {\n\n    const { excludeProvider, ...restProps } = this.props;\n    const tableProps = {\n        ...restProps,\n        dataSource: this.state.dataSource,\n        rowProps: (props, index) => ({\n            index,\n            moveRow: this.moveRow,\n        }),\n        components: {\n            Row: NewRow\n        },\n    };\n\n    return <Table {...tableProps} />;\n  }\n}\n\n\nclass SortableTable extends React.Component {\n    render() {\n        const ComponentName =  DragDropContext(HTML5Backend)(InnerTable);\n        return <ComponentName {...this.props} />;\n    }\n}\n\n\n\nconst result = [{\n    id: '001',\n    time: 1951,\n    title: {name: 'The Old Man and the Sea'},\n}, {\n    id: '002',\n    time: 1925,\n    title: {name: 'the great gatsby'},\n}, {\n    id: '003',\n    time: 1719,\n    title: {name: 'The adventures of Robinson Crusoe'},\n}];\n\nclass Demo extends React.Component {\n    constructor(props) {\n        super(props);\n\n        this.state = {\n            dataSource: result,\n        };\n    }\n\n    onRemove = (id) => {\n        const {dataSource} = this.state;\n        let index = -1;\n        dataSource.forEach((item, i) => {\n            if (item.id === id) {\n                index = i;\n            }\n        });\n        if (index !== -1) {\n            dataSource.splice(index, 1);\n            this.setState({\n                dataSource\n            });\n        }\n    }\n\n    renderOper = (value, index, record) => {\n        return <a onClick={this.onRemove.bind(this, record.id)}>Remove({record.id})</a>;\n    };\n    render() {\n        return (<div>\n            <SortableTable dataSource={this.state.dataSource}>\n                <Table.Column title=\"Id\" dataIndex=\"id\" width={100} lock/>\n                <Table.Column title=\"Title\" dataIndex=\"title.name\" width={400} />\n                <Table.Column title=\"Time\" dataIndex=\"time\" width={300}/>\n                <Table.Column title=\"operate\" cell={this.renderOper} width={300} lock=\"right\"/>\n            </SortableTable>\n        </div>);\n    }\n}\n\n\nReactDOM.render(<Demo />, mountNode);\n","css":".drop-over-downward{\n  border-bottom: 2px dashed #3080fe;\n}\n\n.drop-over-upward{\n  border-top: 2px dashed #3080fe;\n}\n"},"body":"\n\n````jsx\nimport { Table } from '@alifd/next';\nimport { DragDropContext, DragSource, DropTarget } from 'react-dnd';\nimport HTML5Backend from 'react-dnd-html5-backend';\nimport classnames from 'classnames';\n\nconst { SelectionRow } = Table;\n\nlet dragingIndex = -1;\n\nfunction MyRow (props) {\n    const {\n        isDragging,\n        isOver,\n        connectDragSource,\n        connectDropTarget,\n        moveRow,\n        className,\n        ...others\n    } = props;\n\n    const opacity = isDragging ? 0 : 1;\n    const style = { ...others.style, cursor: 'move' };\n\n    const cls = classnames({\n        [className]: className,\n        'drop-over-upward': isOver && others.index < dragingIndex,\n        'drop-over-downward': isOver && others.index > dragingIndex,\n    });\n\n    return (<SelectionRow {...others}\n        style={{ ...style, ...{ opacity } }}\n        className={cls}\n        wrapper={(row) => connectDragSource(connectDropTarget(row))} />);\n}\n\nconst NewRow = DropTarget(\n    'row',\n    {\n        drop(props, monitor) {\n            const dragIndex = monitor.getItem().index;\n            const hoverIndex = props.index;\n\n            if (dragIndex === hoverIndex) {\n                return;\n            }\n\n            props.moveRow(dragIndex, hoverIndex);\n            monitor.getItem().index = hoverIndex;\n        },\n    },\n    (connect, monitor) => ({\n        connectDropTarget: connect.dropTarget(),\n        isOver: monitor.isOver(),\n    }),\n)(\n    DragSource(\n        'row',\n        {\n            beginDrag: props => {\n                dragingIndex = props.index;\n                return {\n                    id: props.record[props.primaryKey],\n                    index: props.rowIndex,\n                };\n            },\n        },\n        (connect, monitor) => ({\n            connectDragSource: connect.dragSource(),\n            isDragging: monitor.isDragging(),\n        }),\n    )(MyRow),\n);\n\nclass InnerTable extends React.Component {\n\n  constructor(props) {\n    super(props);\n    this.state = {\n      dataSource: [...props.dataSource],\n    };\n  }\n\n  componentWillReceiveProps(nextProps) {\n    if (nextProps.dataSource && JSON.stringify(nextProps.dataSource) !==\n      JSON.stringify(this.state.dataSource)) {\n      this.setState({ dataSource: [...nextProps.dataSource] });\n    }\n  }\n\n  moveRow = (dragIndex, hoverIndex) => {\n    const { onSort } = this.props;\n    const dragRow = this.state.dataSource[dragIndex];\n    const dataSource = [...this.state.dataSource];\n    dataSource.splice(dragIndex, 1);\n    dataSource.splice(hoverIndex, 0, dragRow);\n    this.setState({\n      dataSource,\n    });\n\n    onSort && onSort(this.state.dataSource);\n  };\n\n  render() {\n\n    const { excludeProvider, ...restProps } = this.props;\n    const tableProps = {\n        ...restProps,\n        dataSource: this.state.dataSource,\n        rowProps: (props, index) => ({\n            index,\n            moveRow: this.moveRow,\n        }),\n        components: {\n            Row: NewRow\n        },\n    };\n\n    return <Table {...tableProps} />;\n  }\n}\n\n\nclass SortableTable extends React.Component {\n    render() {\n        const ComponentName =  DragDropContext(HTML5Backend)(InnerTable);\n        return <ComponentName {...this.props} />;\n    }\n}\n\n\n\nconst result = [{\n    id: '001',\n    time: 1951,\n    title: {name: 'The Old Man and the Sea'},\n}, {\n    id: '002',\n    time: 1925,\n    title: {name: 'the great gatsby'},\n}, {\n    id: '003',\n    time: 1719,\n    title: {name: 'The adventures of Robinson Crusoe'},\n}];\n\nclass Demo extends React.Component {\n    constructor(props) {\n        super(props);\n\n        this.state = {\n            dataSource: result,\n        };\n    }\n\n    onRemove = (id) => {\n        const {dataSource} = this.state;\n        let index = -1;\n        dataSource.forEach((item, i) => {\n            if (item.id === id) {\n                index = i;\n            }\n        });\n        if (index !== -1) {\n            dataSource.splice(index, 1);\n            this.setState({\n                dataSource\n            });\n        }\n    }\n\n    renderOper = (value, index, record) => {\n        return <a onClick={this.onRemove.bind(this, record.id)}>Remove({record.id})</a>;\n    };\n    render() {\n        return (<div>\n            <SortableTable dataSource={this.state.dataSource}>\n                <Table.Column title=\"Id\" dataIndex=\"id\" width={100} lock/>\n                <Table.Column title=\"Title\" dataIndex=\"title.name\" width={400} />\n                <Table.Column title=\"Time\" dataIndex=\"time\" width={300}/>\n                <Table.Column title=\"operate\" cell={this.renderOper} width={300} lock=\"right\"/>\n            </SortableTable>\n        </div>);\n    }\n}\n\n\nReactDOM.render(<Demo />, mountNode);\n````\n````css\n.drop-over-downward{\n  border-bottom: 2px dashed #3080fe;\n}\n\n.drop-over-upward{\n  border-top: 2px dashed #3080fe;\n}\n````","html":"<script>(function(){'use strict';\n\nvar _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if (\"value\" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();\n\nvar _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };\n\nvar _next = require('@alifd/next');\n\nvar _reactDnd = require('react-dnd');\n\nvar _reactDndHtml5Backend = require('react-dnd-html5-backend');\n\nvar _reactDndHtml5Backend2 = _interopRequireDefault(_reactDndHtml5Backend);\n\nvar _classnames2 = require('classnames');\n\nvar _classnames3 = _interopRequireDefault(_classnames2);\n\nfunction _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }\n\nfunction _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }\n\nfunction _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError(\"Cannot call a class as a function\"); } }\n\nfunction _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError(\"this hasn't been initialised - super() hasn't been called\"); } return call && (typeof call === \"object\" || typeof call === \"function\") ? call : self; }\n\nfunction _inherits(subClass, superClass) { if (typeof superClass !== \"function\" && superClass !== null) { throw new TypeError(\"Super expression must either be null or a function, not \" + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }\n\nfunction _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }\n\nfunction _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }\n\nvar SelectionRow = _next.Table.SelectionRow;\n\n\nvar dragingIndex = -1;\n\nfunction MyRow(props) {\n    var _classnames;\n\n    var isDragging = props.isDragging,\n        isOver = props.isOver,\n        connectDragSource = props.connectDragSource,\n        connectDropTarget = props.connectDropTarget,\n        moveRow = props.moveRow,\n        className = props.className,\n        others = _objectWithoutProperties(props, ['isDragging', 'isOver', 'connectDragSource', 'connectDropTarget', 'moveRow', 'className']);\n\n    var opacity = isDragging ? 0 : 1;\n    var style = _extends({}, others.style, { cursor: 'move' });\n\n    var cls = (0, _classnames3.default)((_classnames = {}, _defineProperty(_classnames, className, className), _defineProperty(_classnames, 'drop-over-upward', isOver && others.index < dragingIndex), _defineProperty(_classnames, 'drop-over-downward', isOver && others.index > dragingIndex), _classnames));\n\n    return React.createElement(SelectionRow, _extends({}, others, {\n        style: _extends({}, style, { opacity: opacity }),\n        className: cls,\n        wrapper: function wrapper(row) {\n            return connectDragSource(connectDropTarget(row));\n        } }));\n}\n\nvar NewRow = (0, _reactDnd.DropTarget)('row', {\n    drop: function drop(props, monitor) {\n        var dragIndex = monitor.getItem().index;\n        var hoverIndex = props.index;\n\n        if (dragIndex === hoverIndex) {\n            return;\n        }\n\n        props.moveRow(dragIndex, hoverIndex);\n        monitor.getItem().index = hoverIndex;\n    }\n}, function (connect, monitor) {\n    return {\n        connectDropTarget: connect.dropTarget(),\n        isOver: monitor.isOver()\n    };\n})((0, _reactDnd.DragSource)('row', {\n    beginDrag: function beginDrag(props) {\n        dragingIndex = props.index;\n        return {\n            id: props.record[props.primaryKey],\n            index: props.rowIndex\n        };\n    }\n}, function (connect, monitor) {\n    return {\n        connectDragSource: connect.dragSource(),\n        isDragging: monitor.isDragging()\n    };\n})(MyRow));\n\nvar InnerTable = function (_React$Component) {\n    _inherits(InnerTable, _React$Component);\n\n    function InnerTable(props) {\n        _classCallCheck(this, InnerTable);\n\n        var _this = _possibleConstructorReturn(this, (InnerTable.__proto__ || Object.getPrototypeOf(InnerTable)).call(this, props));\n\n        _this.moveRow = function (dragIndex, hoverIndex) {\n            var onSort = _this.props.onSort;\n\n            var dragRow = _this.state.dataSource[dragIndex];\n            var dataSource = [].concat(_toConsumableArray(_this.state.dataSource));\n            dataSource.splice(dragIndex, 1);\n            dataSource.splice(hoverIndex, 0, dragRow);\n            _this.setState({\n                dataSource: dataSource\n            });\n\n            onSort && onSort(_this.state.dataSource);\n        };\n\n        _this.state = {\n            dataSource: [].concat(_toConsumableArray(props.dataSource))\n        };\n        return _this;\n    }\n\n    _createClass(InnerTable, [{\n        key: 'componentWillReceiveProps',\n        value: function componentWillReceiveProps(nextProps) {\n            if (nextProps.dataSource && JSON.stringify(nextProps.dataSource) !== JSON.stringify(this.state.dataSource)) {\n                this.setState({ dataSource: [].concat(_toConsumableArray(nextProps.dataSource)) });\n            }\n        }\n    }, {\n        key: 'render',\n        value: function render() {\n            var _this2 = this;\n\n            var _props = this.props,\n                excludeProvider = _props.excludeProvider,\n                restProps = _objectWithoutProperties(_props, ['excludeProvider']);\n\n            var tableProps = _extends({}, restProps, {\n                dataSource: this.state.dataSource,\n                rowProps: function rowProps(props, index) {\n                    return {\n                        index: index,\n                        moveRow: _this2.moveRow\n                    };\n                },\n                components: {\n                    Row: NewRow\n                }\n            });\n\n            return React.createElement(_next.Table, tableProps);\n        }\n    }]);\n\n    return InnerTable;\n}(React.Component);\n\nvar SortableTable = function (_React$Component2) {\n    _inherits(SortableTable, _React$Component2);\n\n    function SortableTable() {\n        _classCallCheck(this, SortableTable);\n\n        return _possibleConstructorReturn(this, (SortableTable.__proto__ || Object.getPrototypeOf(SortableTable)).apply(this, arguments));\n    }\n\n    _createClass(SortableTable, [{\n        key: 'render',\n        value: function render() {\n            var ComponentName = (0, _reactDnd.DragDropContext)(_reactDndHtml5Backend2.default)(InnerTable);\n            return React.createElement(ComponentName, this.props);\n        }\n    }]);\n\n    return SortableTable;\n}(React.Component);\n\nvar result = [{\n    id: '001',\n    time: 1951,\n    title: { name: 'The Old Man and the Sea' }\n}, {\n    id: '002',\n    time: 1925,\n    title: { name: 'the great gatsby' }\n}, {\n    id: '003',\n    time: 1719,\n    title: { name: 'The adventures of Robinson Crusoe' }\n}];\n\nvar Demo = function (_React$Component3) {\n    _inherits(Demo, _React$Component3);\n\n    function Demo(props) {\n        _classCallCheck(this, Demo);\n\n        var _this4 = _possibleConstructorReturn(this, (Demo.__proto__ || Object.getPrototypeOf(Demo)).call(this, props));\n\n        _this4.onRemove = function (id) {\n            var dataSource = _this4.state.dataSource;\n\n            var index = -1;\n            dataSource.forEach(function (item, i) {\n                if (item.id === id) {\n                    index = i;\n                }\n            });\n            if (index !== -1) {\n                dataSource.splice(index, 1);\n                _this4.setState({\n                    dataSource: dataSource\n                });\n            }\n        };\n\n        _this4.renderOper = function (value, index, record) {\n            return React.createElement(\n                'a',\n                { onClick: _this4.onRemove.bind(_this4, record.id) },\n                'Remove(',\n                record.id,\n                ')'\n            );\n        };\n\n        _this4.state = {\n            dataSource: result\n        };\n        return _this4;\n    }\n\n    _createClass(Demo, [{\n        key: 'render',\n        value: function render() {\n            return React.createElement(\n                'div',\n                null,\n                React.createElement(\n                    SortableTable,\n                    { dataSource: this.state.dataSource },\n                    React.createElement(_next.Table.Column, { title: 'Id', dataIndex: 'id', width: 100, lock: true }),\n                    React.createElement(_next.Table.Column, { title: 'Title', dataIndex: 'title.name', width: 400 }),\n                    React.createElement(_next.Table.Column, { title: 'Time', dataIndex: 'time', width: 300 }),\n                    React.createElement(_next.Table.Column, { title: 'operate', cell: this.renderOper, width: 300, lock: 'right' })\n                )\n            );\n        }\n    }]);\n\n    return Demo;\n}(React.Component);\n\nReactDOM.render(React.createElement(Demo, null), mountNode);})()</script><div class=\"highlight\"><pre class=\"language-jsx\"><code class=\"language-jsx\"><span class=\"token keyword\">import</span> <span class=\"token punctuation\">{</span> Table <span class=\"token punctuation\">}</span> <span class=\"token keyword\">from</span> <span class=\"token string\">'@alifd/next'</span><span class=\"token punctuation\">;</span>\n<span class=\"token keyword\">import</span> <span class=\"token punctuation\">{</span> DragDropContext<span class=\"token punctuation\">,</span> DragSource<span class=\"token punctuation\">,</span> DropTarget <span class=\"token punctuation\">}</span> <span class=\"token keyword\">from</span> <span class=\"token string\">'react-dnd'</span><span class=\"token punctuation\">;</span>\n<span class=\"token keyword\">import</span> HTML5Backend <span class=\"token keyword\">from</span> <span class=\"token string\">'react-dnd-html5-backend'</span><span class=\"token punctuation\">;</span>\n<span class=\"token keyword\">import</span> classnames <span class=\"token keyword\">from</span> <span class=\"token string\">'classnames'</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">const</span> <span class=\"token punctuation\">{</span> SelectionRow <span class=\"token punctuation\">}</span> <span class=\"token operator\">=</span> Table<span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">let</span> dragingIndex <span class=\"token operator\">=</span> <span class=\"token operator\">-</span><span class=\"token number\">1</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">function</span> <span class=\"token function\">MyRow</span> <span class=\"token punctuation\">(</span><span class=\"token parameter\">props</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token keyword\">const</span> <span class=\"token punctuation\">{</span>\n        isDragging<span class=\"token punctuation\">,</span>\n        isOver<span class=\"token punctuation\">,</span>\n        connectDragSource<span class=\"token punctuation\">,</span>\n        connectDropTarget<span class=\"token punctuation\">,</span>\n        moveRow<span class=\"token punctuation\">,</span>\n        className<span class=\"token punctuation\">,</span>\n        <span class=\"token operator\">...</span>others\n    <span class=\"token punctuation\">}</span> <span class=\"token operator\">=</span> props<span class=\"token punctuation\">;</span>\n\n    <span class=\"token keyword\">const</span> opacity <span class=\"token operator\">=</span> isDragging <span class=\"token operator\">?</span> <span class=\"token number\">0</span> <span class=\"token punctuation\">:</span> <span class=\"token number\">1</span><span class=\"token punctuation\">;</span>\n    <span class=\"token keyword\">const</span> style <span class=\"token operator\">=</span> <span class=\"token punctuation\">{</span> <span class=\"token operator\">...</span>others<span class=\"token punctuation\">.</span>style<span class=\"token punctuation\">,</span> cursor<span class=\"token punctuation\">:</span> <span class=\"token string\">'move'</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n\n    <span class=\"token keyword\">const</span> cls <span class=\"token operator\">=</span> <span class=\"token function\">classnames</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span>\n        <span class=\"token punctuation\">[</span>className<span class=\"token punctuation\">]</span><span class=\"token punctuation\">:</span> className<span class=\"token punctuation\">,</span>\n        <span class=\"token string\">'drop-over-upward'</span><span class=\"token punctuation\">:</span> isOver <span class=\"token operator\">&amp;&amp;</span> others<span class=\"token punctuation\">.</span>index <span class=\"token operator\">&lt;</span> dragingIndex<span class=\"token punctuation\">,</span>\n        <span class=\"token string\">'drop-over-downward'</span><span class=\"token punctuation\">:</span> isOver <span class=\"token operator\">&amp;&amp;</span> others<span class=\"token punctuation\">.</span>index <span class=\"token operator\">></span> dragingIndex<span class=\"token punctuation\">,</span>\n    <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n\n    <span class=\"token keyword\">return</span> <span class=\"token punctuation\">(</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">SelectionRow</span></span> <span class=\"token spread\"><span class=\"token punctuation\">{</span><span class=\"token punctuation\">...</span><span class=\"token attr-value\">others</span><span class=\"token punctuation\">}</span></span>\n        <span class=\"token attr-name\">style</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token punctuation\">{</span> <span class=\"token operator\">...</span>style<span class=\"token punctuation\">,</span> <span class=\"token operator\">...</span><span class=\"token punctuation\">{</span> opacity <span class=\"token punctuation\">}</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">}</span></span>\n        <span class=\"token attr-name\">className</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span>cls<span class=\"token punctuation\">}</span></span>\n        <span class=\"token attr-name\">wrapper</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">row</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token function\">connectDragSource</span><span class=\"token punctuation\">(</span><span class=\"token function\">connectDropTarget</span><span class=\"token punctuation\">(</span>row<span class=\"token punctuation\">)</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">}</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span>\n\n<span class=\"token keyword\">const</span> NewRow <span class=\"token operator\">=</span> <span class=\"token function\">DropTarget</span><span class=\"token punctuation\">(</span>\n    <span class=\"token string\">'row'</span><span class=\"token punctuation\">,</span>\n    <span class=\"token punctuation\">{</span>\n        <span class=\"token function\">drop</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">props<span class=\"token punctuation\">,</span> monitor</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n            <span class=\"token keyword\">const</span> dragIndex <span class=\"token operator\">=</span> monitor<span class=\"token punctuation\">.</span><span class=\"token function\">getItem</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">.</span>index<span class=\"token punctuation\">;</span>\n            <span class=\"token keyword\">const</span> hoverIndex <span class=\"token operator\">=</span> props<span class=\"token punctuation\">.</span>index<span class=\"token punctuation\">;</span>\n\n            <span class=\"token keyword\">if</span> <span class=\"token punctuation\">(</span>dragIndex <span class=\"token operator\">===</span> hoverIndex<span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n                <span class=\"token keyword\">return</span><span class=\"token punctuation\">;</span>\n            <span class=\"token punctuation\">}</span>\n\n            props<span class=\"token punctuation\">.</span><span class=\"token function\">moveRow</span><span class=\"token punctuation\">(</span>dragIndex<span class=\"token punctuation\">,</span> hoverIndex<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n            monitor<span class=\"token punctuation\">.</span><span class=\"token function\">getItem</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">.</span>index <span class=\"token operator\">=</span> hoverIndex<span class=\"token punctuation\">;</span>\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n    <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n    <span class=\"token punctuation\">(</span><span class=\"token parameter\">connect<span class=\"token punctuation\">,</span> monitor</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span>\n        connectDropTarget<span class=\"token punctuation\">:</span> connect<span class=\"token punctuation\">.</span><span class=\"token function\">dropTarget</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">,</span>\n        isOver<span class=\"token punctuation\">:</span> monitor<span class=\"token punctuation\">.</span><span class=\"token function\">isOver</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">,</span>\n    <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">,</span>\n<span class=\"token punctuation\">)</span><span class=\"token punctuation\">(</span>\n    <span class=\"token function\">DragSource</span><span class=\"token punctuation\">(</span>\n        <span class=\"token string\">'row'</span><span class=\"token punctuation\">,</span>\n        <span class=\"token punctuation\">{</span>\n            <span class=\"token function-variable function\">beginDrag</span><span class=\"token punctuation\">:</span> <span class=\"token parameter\">props</span> <span class=\"token operator\">=></span> <span class=\"token punctuation\">{</span>\n                dragingIndex <span class=\"token operator\">=</span> props<span class=\"token punctuation\">.</span>index<span class=\"token punctuation\">;</span>\n                <span class=\"token keyword\">return</span> <span class=\"token punctuation\">{</span>\n                    id<span class=\"token punctuation\">:</span> props<span class=\"token punctuation\">.</span>record<span class=\"token punctuation\">[</span>props<span class=\"token punctuation\">.</span>primaryKey<span class=\"token punctuation\">]</span><span class=\"token punctuation\">,</span>\n                    index<span class=\"token punctuation\">:</span> props<span class=\"token punctuation\">.</span>rowIndex<span class=\"token punctuation\">,</span>\n                <span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n            <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n        <span class=\"token punctuation\">(</span><span class=\"token parameter\">connect<span class=\"token punctuation\">,</span> monitor</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span>\n            connectDragSource<span class=\"token punctuation\">:</span> connect<span class=\"token punctuation\">.</span><span class=\"token function\">dragSource</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">,</span>\n            isDragging<span class=\"token punctuation\">:</span> monitor<span class=\"token punctuation\">.</span><span class=\"token function\">isDragging</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">,</span>\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">,</span>\n    <span class=\"token punctuation\">)</span><span class=\"token punctuation\">(</span>MyRow<span class=\"token punctuation\">)</span><span class=\"token punctuation\">,</span>\n<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">class</span> <span class=\"token class-name\">InnerTable</span> <span class=\"token keyword\">extends</span> <span class=\"token class-name\">React<span class=\"token punctuation\">.</span>Component</span> <span class=\"token punctuation\">{</span>\n\n  <span class=\"token function\">constructor</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">props</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token keyword\">super</span><span class=\"token punctuation\">(</span>props<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>state <span class=\"token operator\">=</span> <span class=\"token punctuation\">{</span>\n      dataSource<span class=\"token punctuation\">:</span> <span class=\"token punctuation\">[</span><span class=\"token operator\">...</span>props<span class=\"token punctuation\">.</span>dataSource<span class=\"token punctuation\">]</span><span class=\"token punctuation\">,</span>\n    <span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n  <span class=\"token punctuation\">}</span>\n\n  <span class=\"token function\">componentWillReceiveProps</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">nextProps</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token keyword\">if</span> <span class=\"token punctuation\">(</span>nextProps<span class=\"token punctuation\">.</span>dataSource <span class=\"token operator\">&amp;&amp;</span> <span class=\"token constant\">JSON</span><span class=\"token punctuation\">.</span><span class=\"token function\">stringify</span><span class=\"token punctuation\">(</span>nextProps<span class=\"token punctuation\">.</span>dataSource<span class=\"token punctuation\">)</span> <span class=\"token operator\">!==</span>\n      <span class=\"token constant\">JSON</span><span class=\"token punctuation\">.</span><span class=\"token function\">stringify</span><span class=\"token punctuation\">(</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>state<span class=\"token punctuation\">.</span>dataSource<span class=\"token punctuation\">)</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n      <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">setState</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span> dataSource<span class=\"token punctuation\">:</span> <span class=\"token punctuation\">[</span><span class=\"token operator\">...</span>nextProps<span class=\"token punctuation\">.</span>dataSource<span class=\"token punctuation\">]</span> <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n  <span class=\"token punctuation\">}</span>\n\n  <span class=\"token function-variable function\">moveRow</span> <span class=\"token operator\">=</span> <span class=\"token punctuation\">(</span><span class=\"token parameter\">dragIndex<span class=\"token punctuation\">,</span> hoverIndex</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token punctuation\">{</span>\n    <span class=\"token keyword\">const</span> <span class=\"token punctuation\">{</span> onSort <span class=\"token punctuation\">}</span> <span class=\"token operator\">=</span> <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>props<span class=\"token punctuation\">;</span>\n    <span class=\"token keyword\">const</span> dragRow <span class=\"token operator\">=</span> <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>state<span class=\"token punctuation\">.</span>dataSource<span class=\"token punctuation\">[</span>dragIndex<span class=\"token punctuation\">]</span><span class=\"token punctuation\">;</span>\n    <span class=\"token keyword\">const</span> dataSource <span class=\"token operator\">=</span> <span class=\"token punctuation\">[</span><span class=\"token operator\">...</span>this<span class=\"token punctuation\">.</span>state<span class=\"token punctuation\">.</span>dataSource<span class=\"token punctuation\">]</span><span class=\"token punctuation\">;</span>\n    dataSource<span class=\"token punctuation\">.</span><span class=\"token function\">splice</span><span class=\"token punctuation\">(</span>dragIndex<span class=\"token punctuation\">,</span> <span class=\"token number\">1</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    dataSource<span class=\"token punctuation\">.</span><span class=\"token function\">splice</span><span class=\"token punctuation\">(</span>hoverIndex<span class=\"token punctuation\">,</span> <span class=\"token number\">0</span><span class=\"token punctuation\">,</span> dragRow<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">setState</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span>\n      dataSource<span class=\"token punctuation\">,</span>\n    <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n\n    onSort <span class=\"token operator\">&amp;&amp;</span> <span class=\"token function\">onSort</span><span class=\"token punctuation\">(</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>state<span class=\"token punctuation\">.</span>dataSource<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n  <span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n\n  <span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n\n    <span class=\"token keyword\">const</span> <span class=\"token punctuation\">{</span> excludeProvider<span class=\"token punctuation\">,</span> <span class=\"token operator\">...</span>restProps <span class=\"token punctuation\">}</span> <span class=\"token operator\">=</span> <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>props<span class=\"token punctuation\">;</span>\n    <span class=\"token keyword\">const</span> tableProps <span class=\"token operator\">=</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token operator\">...</span>restProps<span class=\"token punctuation\">,</span>\n        dataSource<span class=\"token punctuation\">:</span> <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>state<span class=\"token punctuation\">.</span>dataSource<span class=\"token punctuation\">,</span>\n        <span class=\"token function-variable function\">rowProps</span><span class=\"token punctuation\">:</span> <span class=\"token punctuation\">(</span><span class=\"token parameter\">props<span class=\"token punctuation\">,</span> index</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span>\n            index<span class=\"token punctuation\">,</span>\n            moveRow<span class=\"token punctuation\">:</span> <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>moveRow<span class=\"token punctuation\">,</span>\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">,</span>\n        components<span class=\"token punctuation\">:</span> <span class=\"token punctuation\">{</span>\n            Row<span class=\"token punctuation\">:</span> NewRow\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n    <span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n\n    <span class=\"token keyword\">return</span> <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Table</span></span> <span class=\"token spread\"><span class=\"token punctuation\">{</span><span class=\"token punctuation\">...</span><span class=\"token attr-value\">tableProps</span><span class=\"token punctuation\">}</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token punctuation\">;</span>\n  <span class=\"token punctuation\">}</span>\n<span class=\"token punctuation\">}</span>\n\n\n<span class=\"token keyword\">class</span> <span class=\"token class-name\">SortableTable</span> <span class=\"token keyword\">extends</span> <span class=\"token class-name\">React<span class=\"token punctuation\">.</span>Component</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">const</span> ComponentName <span class=\"token operator\">=</span>  <span class=\"token function\">DragDropContext</span><span class=\"token punctuation\">(</span>HTML5Backend<span class=\"token punctuation\">)</span><span class=\"token punctuation\">(</span>InnerTable<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n        <span class=\"token keyword\">return</span> <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">ComponentName</span></span> <span class=\"token spread\"><span class=\"token punctuation\">{</span><span class=\"token punctuation\">...</span><span class=\"token attr-value\">this</span><span class=\"token punctuation\">.</span><span class=\"token attr-value\">props</span><span class=\"token punctuation\">}</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n<span class=\"token punctuation\">}</span>\n\n\n\n<span class=\"token keyword\">const</span> result <span class=\"token operator\">=</span> <span class=\"token punctuation\">[</span><span class=\"token punctuation\">{</span>\n    id<span class=\"token punctuation\">:</span> <span class=\"token string\">'001'</span><span class=\"token punctuation\">,</span>\n    time<span class=\"token punctuation\">:</span> <span class=\"token number\">1951</span><span class=\"token punctuation\">,</span>\n    title<span class=\"token punctuation\">:</span> <span class=\"token punctuation\">{</span>name<span class=\"token punctuation\">:</span> <span class=\"token string\">'The Old Man and the Sea'</span><span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n<span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span> <span class=\"token punctuation\">{</span>\n    id<span class=\"token punctuation\">:</span> <span class=\"token string\">'002'</span><span class=\"token punctuation\">,</span>\n    time<span class=\"token punctuation\">:</span> <span class=\"token number\">1925</span><span class=\"token punctuation\">,</span>\n    title<span class=\"token punctuation\">:</span> <span class=\"token punctuation\">{</span>name<span class=\"token punctuation\">:</span> <span class=\"token string\">'the great gatsby'</span><span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n<span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span> <span class=\"token punctuation\">{</span>\n    id<span class=\"token punctuation\">:</span> <span class=\"token string\">'003'</span><span class=\"token punctuation\">,</span>\n    time<span class=\"token punctuation\">:</span> <span class=\"token number\">1719</span><span class=\"token punctuation\">,</span>\n    title<span class=\"token punctuation\">:</span> <span class=\"token punctuation\">{</span>name<span class=\"token punctuation\">:</span> <span class=\"token string\">'The adventures of Robinson Crusoe'</span><span class=\"token punctuation\">}</span><span class=\"token punctuation\">,</span>\n<span class=\"token punctuation\">}</span><span class=\"token punctuation\">]</span><span class=\"token punctuation\">;</span>\n\n<span class=\"token keyword\">class</span> <span class=\"token class-name\">Demo</span> <span class=\"token keyword\">extends</span> <span class=\"token class-name\">React<span class=\"token punctuation\">.</span>Component</span> <span class=\"token punctuation\">{</span>\n    <span class=\"token function\">constructor</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">props</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">super</span><span class=\"token punctuation\">(</span>props<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n\n        <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>state <span class=\"token operator\">=</span> <span class=\"token punctuation\">{</span>\n            dataSource<span class=\"token punctuation\">:</span> result<span class=\"token punctuation\">,</span>\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token function-variable function\">onRemove</span> <span class=\"token operator\">=</span> <span class=\"token punctuation\">(</span><span class=\"token parameter\">id</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">const</span> <span class=\"token punctuation\">{</span>dataSource<span class=\"token punctuation\">}</span> <span class=\"token operator\">=</span> <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>state<span class=\"token punctuation\">;</span>\n        <span class=\"token keyword\">let</span> index <span class=\"token operator\">=</span> <span class=\"token operator\">-</span><span class=\"token number\">1</span><span class=\"token punctuation\">;</span>\n        dataSource<span class=\"token punctuation\">.</span><span class=\"token function\">forEach</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">(</span><span class=\"token parameter\">item<span class=\"token punctuation\">,</span> i</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token punctuation\">{</span>\n            <span class=\"token keyword\">if</span> <span class=\"token punctuation\">(</span>item<span class=\"token punctuation\">.</span>id <span class=\"token operator\">===</span> id<span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n                index <span class=\"token operator\">=</span> i<span class=\"token punctuation\">;</span>\n            <span class=\"token punctuation\">}</span>\n        <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n        <span class=\"token keyword\">if</span> <span class=\"token punctuation\">(</span>index <span class=\"token operator\">!==</span> <span class=\"token operator\">-</span><span class=\"token number\">1</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n            dataSource<span class=\"token punctuation\">.</span><span class=\"token function\">splice</span><span class=\"token punctuation\">(</span>index<span class=\"token punctuation\">,</span> <span class=\"token number\">1</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n            <span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">setState</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">{</span>\n                dataSource\n            <span class=\"token punctuation\">}</span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n        <span class=\"token punctuation\">}</span>\n    <span class=\"token punctuation\">}</span>\n\n    <span class=\"token function-variable function\">renderOper</span> <span class=\"token operator\">=</span> <span class=\"token punctuation\">(</span><span class=\"token parameter\">value<span class=\"token punctuation\">,</span> index<span class=\"token punctuation\">,</span> record</span><span class=\"token punctuation\">)</span> <span class=\"token operator\">=></span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">return</span> <span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>a</span> <span class=\"token attr-name\">onClick</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span><span class=\"token function\">onRemove</span><span class=\"token punctuation\">.</span><span class=\"token function\">bind</span><span class=\"token punctuation\">(</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">,</span> record<span class=\"token punctuation\">.</span>id<span class=\"token punctuation\">)</span><span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">Remove(</span><span class=\"token punctuation\">{</span>record<span class=\"token punctuation\">.</span>id<span class=\"token punctuation\">}</span><span class=\"token plain-text\">)</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>a</span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span><span class=\"token punctuation\">;</span>\n    <span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token punctuation\">)</span> <span class=\"token punctuation\">{</span>\n        <span class=\"token keyword\">return</span> <span class=\"token punctuation\">(</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">SortableTable</span></span> <span class=\"token attr-name\">dataSource</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>state<span class=\"token punctuation\">.</span>dataSource<span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Table.Column</span></span> <span class=\"token attr-name\">title</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>Id<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">dataIndex</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>id<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">width</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token number\">100</span><span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">lock</span><span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Table.Column</span></span> <span class=\"token attr-name\">title</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>Title<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">dataIndex</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>title.name<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">width</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token number\">400</span><span class=\"token punctuation\">}</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Table.Column</span></span> <span class=\"token attr-name\">title</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>Time<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">dataIndex</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>time<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">width</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token number\">300</span><span class=\"token punctuation\">}</span></span><span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n                </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Table.Column</span></span> <span class=\"token attr-name\">title</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>operate<span class=\"token punctuation\">\"</span></span> <span class=\"token attr-name\">cell</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token keyword\">this</span><span class=\"token punctuation\">.</span>renderOper<span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">width</span><span class=\"token script language-javascript\"><span class=\"token script-punctuation punctuation\">=</span><span class=\"token punctuation\">{</span><span class=\"token number\">300</span><span class=\"token punctuation\">}</span></span> <span class=\"token attr-name\">lock</span><span class=\"token attr-value\"><span class=\"token punctuation\">=</span><span class=\"token punctuation\">\"</span>right<span class=\"token punctuation\">\"</span></span><span class=\"token punctuation\">/></span></span><span class=\"token plain-text\">\n            </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span><span class=\"token class-name\">SortableTable</span></span><span class=\"token punctuation\">></span></span><span class=\"token plain-text\">\n        </span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;/</span>div</span><span class=\"token punctuation\">></span></span><span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span>\n    <span class=\"token punctuation\">}</span>\n<span class=\"token punctuation\">}</span>\n\n\nReactDOM<span class=\"token punctuation\">.</span><span class=\"token function\">render</span><span class=\"token punctuation\">(</span><span class=\"token tag\"><span class=\"token tag\"><span class=\"token punctuation\">&lt;</span><span class=\"token class-name\">Demo</span></span> <span class=\"token punctuation\">/></span></span><span class=\"token punctuation\">,</span> mountNode<span class=\"token punctuation\">)</span><span class=\"token punctuation\">;</span></code></pre></div><style type=\"text/css\">.drop-over-downward{\n  border-bottom: 2px dashed #3080fe;\n}\n\n.drop-over-upward{\n  border-top: 2px dashed #3080fe;\n}</style><div class=\"highlight\"><pre class=\"language-css\"><code class=\"language-css\"><span class=\"token selector\">.drop-over-downward</span><span class=\"token punctuation\">{</span>\n  <span class=\"token property\">border-bottom</span><span class=\"token punctuation\">:</span> 2px dashed #3080fe<span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span>\n\n<span class=\"token selector\">.drop-over-upward</span><span class=\"token punctuation\">{</span>\n  <span class=\"token property\">border-top</span><span class=\"token punctuation\">:</span> 2px dashed #3080fe<span class=\"token punctuation\">;</span>\n<span class=\"token punctuation\">}</span></code></pre></div>"}